@@ -1,6 +1,6 @@
 /*
  * HopSortFilterProxyModel.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
@@ -29,8 +29,7 @@
  *
  * \brief Proxy model for sorting hops.
  */
-class HopSortFilterProxyModel : public QSortFilterProxyModel
-{
+class HopSortFilterProxyModel : public QSortFilterProxyModel {
    Q_OBJECT
 
 public:
