@@ -1,7 +1,8 @@
 /*
  * InstructionWidget.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -17,11 +18,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _INGREDIENTWIDGET_H
-#define   _INGREDIENTWIDGET_H
-
-class InstructionWidget;
+#ifndef INSTRUCTIONWIDGET_H
+#define INSTRUCTIONWIDGET_H
+#pragma once
 
 #include "ui_instructionWidget.h"
 #include <QWidget>
@@ -35,7 +34,6 @@ class Instruction;
 
 /*!
  * \class InstructionWidget
- * \author Philip G. Lee
  *
  * \brief View/controller widget that views/edits recipe instructions.
  */
@@ -52,7 +50,6 @@ public:
 
 public slots:
    void setDirections();
-   void setHasTimer();
    void setTimerValue(QString value);
    void setCompleted();
 
@@ -60,7 +57,7 @@ public slots:
 private:
    void showChanges();
    void makeEverythingInactive();
-   
+
    Instruction* insObs;
    TimerWidget* timer;
 };
