@@ -1,6 +1,6 @@
 /*
  * MashDesigner.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Dan Cavanagh <dan@dancavanagh.com>
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
@@ -40,41 +40,48 @@ MashDesigner::MashDesigner(QWidget * parent) : QDialog     {parent},
                                                addedWater_l{0} {
    this->setupUi(this);
 
-   this->label_zeroVol->setText(Measurement::displayAmount(Measurement::Amount{0, Measurement::Units::liters}));
+   // .:TODO:. Would be good to make the label & field naming a bit more consistent in the .ui file
+   SMART_FIELD_INIT_FS(MashDesigner, label_targetTemp, lineEdit_temp, double, Measurement::PhysicalQuantity::Temperature, 1); // Target temp.
+   SMART_FIELD_INIT_FS(MashDesigner, label_stepTime,   lineEdit_time, double, Measurement::PhysicalQuantity::Time,        0); // Time
+
+   this->label_zeroVol ->setText(Measurement::displayAmount(Measurement::Amount{0, Measurement::Units::liters}));
    this->label_zeroWort->setText(Measurement::displayAmount(Measurement::Amount{0, Measurement::Units::liters}));
 
    // Update temp slider when we move amount slider.
-   connect(horizontalSlider_amount, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateTempSlider);
+   //
+   // Here and below, we connect to valueChanged rather than sliderMoved as, otherwise, we don't receive any signal if
+   // the keyboard is used to move the slider.
+   connect(horizontalSlider_amount, &QAbstractSlider::valueChanged, this, &MashDesigner::updateTempSlider);
    // Update amount slider when we move temp slider.
-   connect(horizontalSlider_temp, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateAmtSlider);
+   connect(horizontalSlider_temp,   &QAbstractSlider::valueChanged, this, &MashDesigner::updateAmtSlider);
    // Update tun fullness bar when either slider moves.
-   connect(horizontalSlider_amount, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateFullness);
-   connect(horizontalSlider_temp, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateFullness);
+   connect(horizontalSlider_amount, &QAbstractSlider::valueChanged, this, &MashDesigner::updateFullness);
+   connect(horizontalSlider_temp,   &QAbstractSlider::valueChanged, this, &MashDesigner::updateFullness);
    // Update amount/temp text when sliders move.
-   connect(horizontalSlider_amount, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateAmt);
-   connect(horizontalSlider_amount, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateTemp);
-   connect(horizontalSlider_temp, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateAmt);
-   connect(horizontalSlider_temp, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateTemp);
+   connect(horizontalSlider_amount, &QAbstractSlider::valueChanged, this, &MashDesigner::updateAmt);
+   connect(horizontalSlider_amount, &QAbstractSlider::valueChanged, this, &MashDesigner::updateTemp);
+   connect(horizontalSlider_temp,   &QAbstractSlider::valueChanged, this, &MashDesigner::updateAmt);
+   connect(horizontalSlider_temp,   &QAbstractSlider::valueChanged, this, &MashDesigner::updateTemp);
    // Update collected wort when sliders move.
-   connect(horizontalSlider_amount, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateCollectedWort);
-   connect(horizontalSlider_temp, &QAbstractSlider::sliderMoved, this, &MashDesigner::updateCollectedWort);
+   connect(horizontalSlider_amount, &QAbstractSlider::valueChanged, this, &MashDesigner::updateCollectedWort);
+   connect(horizontalSlider_temp,   &QAbstractSlider::valueChanged, this, &MashDesigner::updateCollectedWort);
    // Save the target temp whenever it's changed.
-   connect(lineEdit_temp, &BtLineEdit::textModified, this, &MashDesigner::saveTargetTemp);
+   connect(lineEdit_temp,           &SmartLineEdit::textModified,  this, &MashDesigner::saveTargetTemp);
    // Move to next step.
-   connect(pushButton_next, &QAbstractButton::clicked, this, &MashDesigner::proceed);
+   connect(pushButton_next,         &QAbstractButton::clicked,     this, &MashDesigner::proceed);
    // Do correct calcs when the mash step type is selected.
    connect(comboBox_type, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &MashDesigner::typeChanged);
 
    // I still dislike this part. But I also need to "fix" the form
    // connect(checkBox_batchSparge, SIGNAL(clicked()), this, SLOT(updateMaxAmt()));
-   connect(pushButton_finish, &QAbstractButton::clicked, this, &MashDesigner::saveAndClose);
+   connect(pushButton_finish,       &QAbstractButton::clicked,     this, &MashDesigner::saveAndClose);
 
    return;
 }
 
-void MashDesigner::proceed()
-{
+void MashDesigner::proceed() {
    nextStep(++curStep);
+   return;
 }
 
 void MashDesigner::setRecipe(Recipe* rec) {
@@ -154,8 +161,8 @@ void MashDesigner::saveStep() {
    this->mashStep->setName(this->lineEdit_name->text());
    this->mashStep->setType(static_cast<MashStep::Type>(comboBox_type->currentIndex()));
    // Bound the target temperature to what can be achieved
-   this->mashStep->setStepTemp_c(this->bound_temp_c(this->lineEdit_temp->toSI().quantity));
-   this->mashStep->setStepTime_min(lineEdit_time->toSI().quantity);
+   this->mashStep->setStepTemp_c(this->bound_temp_c(this->lineEdit_temp->toCanonical().quantity()));
+   this->mashStep->setStepTime_min(lineEdit_time->toCanonical().quantity());
 
    // finish a few things -- this may be premature optimization
    if (isInfusion()) {
@@ -169,7 +176,7 @@ void MashDesigner::saveStep() {
 }
 
 double MashDesigner::stepTemp_c() {
-   return lineEdit_temp->toSI().quantity;
+   return lineEdit_temp->toCanonical().quantity();
 }
 
 bool MashDesigner::heating() {
@@ -351,7 +358,7 @@ bool MashDesigner::initializeMash() {
    // Order matters. Don't do this until every that could return false has
    this->mash->setTunSpecificHeat_calGC(this->equip->tunSpecificHeat_calGC());
    this->mash->setTunWeight_kg(this->equip->tunWeight_kg());
-   this->mash->setTunTemp_c(Measurement::qStringToSI(dialogText, Measurement::PhysicalQuantity::Temperature).quantity);
+   this->mash->setTunTemp_c(Measurement::qStringToSI(dialogText, Measurement::PhysicalQuantity::Temperature).quantity());
 
    this->curStep = 0;
    this->addedWater_l = 0;
@@ -586,7 +593,7 @@ void MashDesigner::saveTargetTemp() {
    double temp = this->bound_temp_c(this->stepTemp_c());
 
    // be nice and reset the field so it displays in proper units
-   this->lineEdit_temp->setText(temp);
+   this->lineEdit_temp->setAmount(temp);
    if (this->mashStep) {
       this->mashStep->setStepTemp_c(temp);
    }
@@ -646,12 +653,12 @@ double MashDesigner::getDecoctionAmount_l() {
 
 bool MashDesigner::isBatchSparge() const {
    MashStep::Type stepType = type();
-   return (stepType == MashStep::batchSparge);
+   return (stepType == MashStep::Type::batchSparge);
 }
 
 bool MashDesigner::isFlySparge() const {
    MashStep::Type stepType = type();
-   return (stepType == MashStep::flySparge);
+   return (stepType == MashStep::Type::flySparge);
 }
 
 bool MashDesigner::isSparge() const {
@@ -660,17 +667,17 @@ bool MashDesigner::isSparge() const {
 
 bool MashDesigner::isInfusion() const {
    MashStep::Type stepType = type();
-   return (stepType == MashStep::Infusion || isSparge());
+   return (stepType == MashStep::Type::Infusion || isSparge());
 }
 
 bool MashDesigner::isDecoction() const {
    MashStep::Type stepType = type();
-   return (stepType == MashStep::Decoction);
+   return (stepType == MashStep::Type::Decoction);
 }
 
 bool MashDesigner::isTemperature() const {
    MashStep::Type stepType = type();
-   return (stepType == MashStep::Temperature);
+   return (stepType == MashStep::Type::Temperature);
 }
 
 MashStep::Type MashDesigner::type() const {
