@@ -1,7 +1,8 @@
 /*
  * MashStepEditor.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
  * - Jeff Bailey <skydvr38@verizon.net>
+ * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
@@ -18,24 +19,23 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _MASHSTEPEDITOR_H
-#define   _MASHSTEPEDITOR_H
-
-class MashStepEditor;
+#ifndef MASHSTEPEDITOR_H
+#define MASHSTEPEDITOR_H
+#include <memory>
 
 #include <QDialog>
 #include <QWidget>
 #include <QMetaProperty>
 #include <QVariant>
+
 #include "ui_mashStepEditor.h"
 
 // Forward declarations.
 class MashStep;
+class Mash;
 
 /*!
  * \class MashStepEditor
- * \author Philip G. Lee
  *
  * \brief View/controller dialog for editing mash steps.
  */
@@ -43,13 +43,14 @@ class MashStepEditor : public QDialog, public Ui::mashStepEditor
 {
    Q_OBJECT
 public:
-   MashStepEditor(QWidget* parent=0);
+   MashStepEditor(QWidget* parent=nullptr);
    virtual ~MashStepEditor() {}
 
+   void setMashStep(std::shared_ptr<MashStep> step);
+
 public slots:
    void saveAndClose();
    //! View/edit the given mash step.
-   void setMashStep(MashStep* step);
    void close();
    /*!
     * Grays out irrelevant portions of the dialog.
@@ -65,8 +66,7 @@ private:
     */
    void showChanges(QMetaProperty* metaProp = 0);
    void clear();
-   MashStep* obs;
+   std::shared_ptr<MashStep> obs;
 };
 
-#endif   /* _MASHSTEPEDITOR_H */
-
+#endif
