@@ -95,7 +95,7 @@ PrintAndPreviewDialog::~PrintAndPreviewDialog() = default;
  *
  * @param e Event object
  */
-void PrintAndPreviewDialog::showEvent(QShowEvent *e) {
+void PrintAndPreviewDialog::showEvent([[maybe_unused]] QShowEvent *e) {
    setVisible(true);
    collectRecipe();
    currentlySelectedPageSize = printer->pageLayout().pageSize();
@@ -103,29 +103,28 @@ void PrintAndPreviewDialog::showEvent(QShowEvent *e) {
    comboBox_PaperFormatSelector->setCurrentIndex(index);
    comboBox_PaperFormatSelector->repaint();
    updatePreview();
+   return;
 }
 
 /**
  * @brief Gets the Recipe from MainWindow and sets it to the respective formatters.
- *
  */
 void PrintAndPreviewDialog::collectRecipe() {
    selectedRecipe = mainWindow->currentRecipe();
    recipeFormatter->setRecipe(selectedRecipe);
    brewDayFormatter->setRecipe(selectedRecipe);
    label_CurrentRecipe->setText((selectedRecipe != nullptr) ? selectedRecipe->name() : "NULL");
+   return;
 }
 
 /**
  * @brief Collects the available printers on the computer and saves the list to the comboBox.
- *
  */
 void PrintAndPreviewDialog::collectPrinterInfo() {
    //Getting the list of available printers on the system and adding them to the combobox for user selection.
    comboBox_PrinterSelector->addItems(QStringList(QPrinterInfo().availablePrinterNames()));
    //If there are no printers installed on the system we disable the Paper output and select the PDF as default.
-   if (comboBox_PrinterSelector->count() == 0)
-   {
+   if (comboBox_PrinterSelector->count() == 0) {
       radioButton_OutputPDF->setChecked(true);
       radioButton_OutputPaper->setEnabled(false);
    }
@@ -133,48 +132,40 @@ void PrintAndPreviewDialog::collectPrinterInfo() {
    comboBox_PrinterSelector->setCurrentText(QPrinterInfo().defaultPrinterName());
 
    collectSupportedPageSizes();
-
+   return;
 }
 
 /**
  * @brief Collect the supported Paper sizes from the selected printer.
- *
  */
-void PrintAndPreviewDialog::collectSupportedPageSizes()
-{
+void PrintAndPreviewDialog::collectSupportedPageSizes() {
    PageSizeMap.clear();
    QPrinterInfo printerInfo(*printer);
    QList<QPageSize> supportedPageSizeList;
-   if (radioButton_OutputPaper->isChecked())
-   {
+   if (radioButton_OutputPaper->isChecked()) {
       supportedPageSizeList = printerInfo.supportedPageSizes();
-   }
-   else if (radioButton_OutputPDF->isChecked())
-   {
+   } else if (radioButton_OutputPDF->isChecked()) {
       qDebug() << "generating a list of page sizes as there is no printer intalled on the system";
       supportedPageSizeList = generatePageSizeList();
    }
-   foreach(QPageSize pageSize, supportedPageSizeList)
-   {
+   foreach(QPageSize pageSize, supportedPageSizeList) {
       PageSizeMap.insert(pageSize.name(), pageSize);
       comboBox_PaperFormatSelector->addItem(pageSize.name());
    }
-   if (comboBox_PaperFormatSelector->findText(currentlySelectedPageSize.name(), Qt::MatchFlag::MatchContains) > -1)
+   if (comboBox_PaperFormatSelector->findText(currentlySelectedPageSize.name(), Qt::MatchFlag::MatchContains) > -1) {
       comboBox_PaperFormatSelector->setCurrentText(currentlySelectedPageSize.name());
-   else
-   {
+   } else {
       currentlySelectedPageSize = QPageSize((QPageSize::PageSizeId)0);
       comboBox_PaperFormatSelector->setCurrentIndex(0);
    }
+   return;
 }
 
 
-QList<QPageSize> PrintAndPreviewDialog::generatePageSizeList()
-{
+QList<QPageSize> PrintAndPreviewDialog::generatePageSizeList() {
    QList<QPageSize> result;
 
-   for(int itor = 0; itor < QPageSize::LastPageSize; itor++)
-   {
+   for (int itor = 0; itor < QPageSize::LastPageSize; itor++) {
       QPageSize key((QPageSize::PageSizeId)itor);
       result.append(key);
    }
@@ -187,45 +178,40 @@ QList<QPageSize> PrintAndPreviewDialog::generatePageSizeList()
  *
  */
 void PrintAndPreviewDialog::setupConnections() {
-   //Preview windows connections for drawing the previewed document. connects to the printer.
+   // Preview windows connections for drawing the previewed document. connects to the printer.
    connect(previewWidget, &QPrintPreviewWidget::paintRequested, this, &PrintAndPreviewDialog::printDocument);
 
-   //Radiobuttons connections to update settings for output.
-   connect(buttonGroup, QOverload<QAbstractButton *, bool>::of(&QButtonGroup::buttonToggled), [=](QAbstractButton *button, bool checked) { outputRadioButtonsClicked (); });
+   // Radiobuttons connections to update settings for output.
+   connect(buttonGroup,   QOverload<QAbstractButton *, bool>::of(&QButtonGroup::buttonToggled), this, &PrintAndPreviewDialog::outputRadioButtonsClicked);
 
-   //Radiobuttons connections to update the orientation on the document.
-   connect(buttonGroup_2, QOverload<QAbstractButton *, bool>::of(&QButtonGroup::buttonToggled), [=](QAbstractButton *button, bool checked) { orientationRadioButtonsClicked(); });
+   // Radiobuttons connections to update the orientation on the document.
+   connect(buttonGroup_2, QOverload<QAbstractButton *, bool>::of(&QButtonGroup::buttonToggled), this, &PrintAndPreviewDialog::orientationRadioButtonsClicked);
 
-   //updates the selelected printer.
-   connect(comboBox_PrinterSelector, QOverload<int>::of(&QComboBox::currentIndexChanged), [=](int index){
-      selectedPrinterChanged(index);
-   });
+   // Updates the selected printer.
+   connect(comboBox_PrinterSelector,     QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PrintAndPreviewDialog::selectedPrinterChanged);
 
-   //updates the selected Paper size
-   connect(comboBox_PaperFormatSelector, QOverload<int>::of(&QComboBox::currentIndexChanged), [=](int index) {
-      selectedPaperChanged(index);
-   });
+   // Updates the selected Paper size
+   connect(comboBox_PaperFormatSelector, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &PrintAndPreviewDialog::selectedPaperChanged);
 
    connect(Button_Cancel, &QPushButton::clicked, [this]() {
       setVisible(false);
    });
 
-   //This will Printout the document and close the dialog
-   connect(Button_Print, &QPushButton::clicked, [this]() {
-      handlePrinting();
-   });
+   // This will print out the document and close the dialog
+   connect(Button_Print,                   &QPushButton::clicked,       this, &PrintAndPreviewDialog::handlePrinting);
 
-   //Connect the Recipe and BrewInstructions checkboxes to update the preview when toggled
-   connect(checkBox_Recipe,                 &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxRecipe_toggle);
-   connect(checkBox_BrewdayInstructions,    &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxBrewday_toggle);
+   // Connect the Recipe and BrewInstructions checkboxes to update the preview when toggled
+   connect(checkBox_Recipe,                &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxRecipe_toggle);
+   connect(checkBox_BrewdayInstructions,   &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxBrewday_toggle);
 
-   connect(checkBox_inventoryAll,           &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryAll_toggle);
-   connect(checkBox_inventoryFermentables,  &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
-   connect(checkBox_inventoryHops,          &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
-   connect(checkBox_inventoryMicellaneous,  &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
-   connect(checkBox_inventoryYeast,         &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
+   connect(checkBox_inventoryAll,          &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryAll_toggle);
+   connect(checkBox_inventoryFermentables, &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
+   connect(checkBox_inventoryHops,         &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
+   connect(checkBox_inventoryMicellaneous, &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
+   connect(checkBox_inventoryYeast,        &QCheckBox::toggled,         this, &PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle);
 
-   connect(verticalTabWidget,               &QTabWidget::currentChanged, this, &PrintAndPreviewDialog::verticalTabWidget_currentChanged);
+   connect(verticalTabWidget,              &QTabWidget::currentChanged, this, &PrintAndPreviewDialog::verticalTabWidget_currentChanged);
+   return;
 }
 
 /**
@@ -233,26 +219,27 @@ void PrintAndPreviewDialog::setupConnections() {
  *
  * @param checked
  */
-void PrintAndPreviewDialog::checkBoxRecipe_toggle(bool checked)
-{
+void PrintAndPreviewDialog::checkBoxRecipe_toggle([[maybe_unused]] bool checked) {
    updatePreview();
+   return;
 }
 
 /**
- * @brief handles the breDay checkbox toggle action
+ * @brief handles the brew day checkbox toggle action
  *
  * @param checked
  */
-void PrintAndPreviewDialog::checkBoxBrewday_toggle(bool checked)
-{
-   //first off, we always need to have something to export/print, so if brewday instructions is unchecked the recipe will automatically be selected.
+void PrintAndPreviewDialog::checkBoxBrewday_toggle([[maybe_unused]] bool checked) {
+   // First off, we always need to have something to export/print, so if brewday instructions is unchecked the recipe
+   // will automatically be selected.
    checkBox_Recipe->setChecked( (checkBox_BrewdayInstructions->isChecked()) ? checkBox_Recipe->isChecked() : true );
 
    // We enable the Recipe checkbox only if the brewday checkbox is checked.
    checkBox_Recipe->setEnabled( checkBox_BrewdayInstructions->isChecked() );
 
-   //update the view accordingly
+   // Update the view accordingly
    updatePreview();
+   return;
 }
 
 /**
@@ -260,8 +247,7 @@ void PrintAndPreviewDialog::checkBoxBrewday_toggle(bool checked)
  *
  * @param checked
  */
-void PrintAndPreviewDialog::checkBoxInventoryAll_toggle(bool checked)
-{
+void PrintAndPreviewDialog::checkBoxInventoryAll_toggle(bool checked) {
    checkBox_inventoryFermentables->setEnabled(!checked);
    checkBox_inventoryHops->setEnabled(!checked);
    checkBox_inventoryYeast->setEnabled(!checked);
@@ -271,6 +257,7 @@ void PrintAndPreviewDialog::checkBoxInventoryAll_toggle(bool checked)
    checkBox_inventoryYeast->setChecked(true);
    checkBox_inventoryMicellaneous->setChecked(true);
    updatePreview();
+   return;
 }
 
 /**
@@ -278,9 +265,9 @@ void PrintAndPreviewDialog::checkBoxInventoryAll_toggle(bool checked)
  *
  * @param checked
  */
-void PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle(bool checked)
-{
+void PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle([[maybe_unused]] bool checked) {
    updatePreview();
+   return;
 }
 
 /**
@@ -288,9 +275,9 @@ void PrintAndPreviewDialog::checkBoxInventoryIngredient_toggle(bool checked)
  *
  * @param index
  */
-void PrintAndPreviewDialog::verticalTabWidget_currentChanged(int index)
-{
+void PrintAndPreviewDialog::verticalTabWidget_currentChanged([[maybe_unused]] int index) {
    updatePreview();
+   return;
 }
 
 /**
@@ -298,13 +285,10 @@ void PrintAndPreviewDialog::verticalTabWidget_currentChanged(int index)
  *
  */
 void PrintAndPreviewDialog::handlePrinting() {
-   //make it short if we are printing to paper.
-   if (radioButton_OutputPaper->isChecked())
-   {
+   // Make it short if we are printing to paper.
+   if (radioButton_OutputPaper->isChecked()) {
       previewWidget->print();
-   }
-   else
-   {
+   } else {
       // if we are not sending to printer we need to save a file.
       QString fileDialogFilter = (radioButton_OutputPDF->isChecked()) ? "PDF (*.pdf)" : "HTML (*.html)";
       QString filename = QFileDialog::getSaveFileName(
@@ -314,17 +298,13 @@ void PrintAndPreviewDialog::handlePrinting() {
          fileDialogFilter
          );
       qDebug() << Q_FUNC_INFO << "Filename to save: " << filename;
-      if (radioButton_OutputPDF->isChecked())
-      {
+      if (radioButton_OutputPDF->isChecked()) {
          printer->setOutputFormat(QPrinter::PdfFormat);
          printer->setOutputFileName(filename);
          previewWidget->print();
-      }
-      else
-      {
+      } else {
          QFile file(filename);
-         if (!file.open(QIODevice::WriteOnly | QIODevice::Text))
-         {
+         if (!file.open(QIODevice::WriteOnly | QIODevice::Text)) {
             qWarning() << Q_FUNC_INFO << tr("File %1 filname << could not be saved").arg(filename);
             QMessageBox msgbox(this);
             msgbox.setWindowTitle(tr("Error saving file"));
@@ -337,8 +317,9 @@ void PrintAndPreviewDialog::handlePrinting() {
          file.close();
       }
    }
-   //Closing down the dialog.
+   // Closing down the dialog.
    setVisible(false);
+   return;
 }
 
 /**
@@ -347,7 +328,7 @@ void PrintAndPreviewDialog::handlePrinting() {
  * @param checked
  */
 void PrintAndPreviewDialog::updatePreview() {
-   if ( ! radioButton_OutputHTML->isChecked()) {
+   if (!radioButton_OutputHTML->isChecked()) {
       previewWidget->updatePreview();
    } else {
       QString pDoc = "";
@@ -394,7 +375,7 @@ void PrintAndPreviewDialog::updatePreview() {
  *
  * @param checked
  */
-void PrintAndPreviewDialog::resetAndClose(bool checked) {
+void PrintAndPreviewDialog::resetAndClose([[maybe_unused]] bool checked) {
    setVisible(false);
    return;
 }
@@ -404,7 +385,7 @@ void PrintAndPreviewDialog::resetAndClose(bool checked) {
  *
  * @param index
  */
-void PrintAndPreviewDialog::selectedPaperChanged(int index) {
+void PrintAndPreviewDialog::selectedPaperChanged([[maybe_unused]] int index) {
    if (PageSizeMap.empty()) {
       return;
    }
@@ -429,7 +410,6 @@ void PrintAndPreviewDialog::selectedPrinterChanged(int index) {
 
 /**
  * @brief handles the output radio buttons signal.
- *
  */
 void PrintAndPreviewDialog::outputRadioButtonsClicked() {
    setPrintingControls();
@@ -449,34 +429,33 @@ void PrintAndPreviewDialog::orientationRadioButtonsClicked() {
  * @brief Sets the Printing settings and enables/disables controls accordingly.
  */
 void PrintAndPreviewDialog::setPrintingControls() {
-   // First off, The Printer selector either needs to be disabled when you output to PDF or HTML, or you set the output
+   // First off, the printer selector either needs to be disabled when you output to PDF or HTML, or you set the output
    // selector to say like "QT PDF exporter" or something.
    // For now, let's disable it.
    comboBox_PrinterSelector->setEnabled    ( radioButton_OutputPaper->isChecked() );
 
-   //Lets set the Papersize selector to be the inverse of radiobutton_OutputHTML.
+   // Let's set the Papersize selector to be the inverse of radiobutton_OutputHTML.
    comboBox_PaperFormatSelector->setEnabled( ! radioButton_OutputHTML->isChecked() );
 
 
-   //if HTML is selected the orientation and papersize is not relavant so lets set them to the inverse of radiobutton_OutputHTML.
+   // If HTML is selected the orientation and papersize is not relavant so lets set them to the inverse of
+   // radiobutton_OutputHTML.
    groupBox_Orientation->setEnabled        ( ! radioButton_OutputHTML->isChecked() );
    groupBox_PrinterSettings->setEnabled    ( ! radioButton_OutputHTML->isChecked() );
 
-   //Only set this as "print" if we are printing to paper, else it is set to "save as"
+   // Only set this as "print" if we are printing to paper, else it is set to "save as"
    Button_Print->setText((radioButton_OutputPaper->isChecked()) ? "Print" : "Save as");
 
-   //setting up printer accordingly
-   if (radioButton_OutputPaper->isChecked())
-   {
+   // Setting up printer accordingly
+   if (radioButton_OutputPaper->isChecked()) {
       printer->setOutputFormat(QPrinter::OutputFormat::NativeFormat);
       printer->setPrinterName(comboBox_PrinterSelector->currentText());
-   }
-   else if (radioButton_OutputPDF->isChecked())
-   {
+   } else if (radioButton_OutputPDF->isChecked()) {
       printer->setOutputFormat(QPrinter::OutputFormat::PdfFormat);
    }
    collectSupportedPageSizes();
-   //setting up views correctly.
+
+   // Setting up views correctly.
    updatePreview();
 
    return;
@@ -487,14 +466,14 @@ void PrintAndPreviewDialog::setPrintingControls() {
  *        This is changed according to when output is changed.
  */
 void PrintAndPreviewDialog::setupPreviewWidgets() {
-   //Setting up the Document preview for Paper and PDF
+   // Setting up the Document preview for Paper and PDF
    PrintAndPreviewDialog::verticalLayout_PrintPreviewWidget->addWidget ( previewWidget );
    previewWidget->setMinimumWidth(300);
    previewWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    previewWidget->setZoomMode(QPrintPreviewWidget::FitInView);
    previewWidget->show();
 
-   //setting up the Document preview for HTML, we're hiding this to begin with.
+   // Setting up the Document preview for HTML, we're hiding this to begin with.
    verticalLayout_PrintPreviewWidget->addWidget( htmlDocument );
    htmlDocument->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    htmlDocument->hide();
@@ -510,33 +489,31 @@ void PrintAndPreviewDialog::setupPreviewWidgets() {
  * @param printer PagedPaintingDevice (QT) Printer to use for printout.
  */
 void PrintAndPreviewDialog::printDocument(QPrinter * printer) {
-   if ( mainWindow->currentRecipe() == nullptr)
+   if ( mainWindow->currentRecipe() == nullptr) {
       return;
+   }
    recipeFormatter->setRecipe(mainWindow->currentRecipe());
-   //Setting up a blank page for drawing.
+   // Setting up a blank page for drawing.
    QTextBrowser textBrowser;
    QString hDoc = "";
-   //if we are watching the Recipe tab we should print recipe stuff.
-   if (Ui_BtPrintAndPreview::verticalTabWidget->currentIndex() == 0)
-   {
-      /*
-      all of the below code to generate the printout will be subject to change and refactoring when I get around to
-      making the template editor for printouts where you can save your templates and use them or share them
-      with other BT users.
-      */
+   // If we are watching the Recipe tab we should print recipe stuff.
+   if (Ui_BtPrintAndPreview::verticalTabWidget->currentIndex() == 0) {
+      //
+      // TODO: All of the below code to generate the printout will be subject to change and refactoring when I get
+      //       around to making the template editor for printouts where you can save your templates and use them or
+      //       share them with other BT users.
+      //
       hDoc += recipeFormatter->buildHtmlHeader();
-      if ( checkBox_Recipe->isChecked())
-      {
+      if (checkBox_Recipe->isChecked()) {
          hDoc += recipeFormatter->getHtmlFormat();
       }
-      if (checkBox_BrewdayInstructions->isChecked())
-      {
+
+      if (checkBox_BrewdayInstructions->isChecked()) {
          hDoc += brewDayFormatter->buildInstructionHtml();
       }
+
       hDoc += recipeFormatter->buildHtmlFooter();
-   }
-   else if (verticalTabWidget->currentIndex() == 1)
-   {
+   } else if (verticalTabWidget->currentIndex() == 1) {
       InventoryFormatter::HtmlGenerationFlags flags = static_cast<InventoryFormatter::HtmlGenerationFlags>(
          checkBox_inventoryFermentables->isChecked() * InventoryFormatter::FERMENTABLES   +
          checkBox_inventoryHops->isChecked()         * InventoryFormatter::HOPS           +
@@ -546,7 +523,7 @@ void PrintAndPreviewDialog::printDocument(QPrinter * printer) {
       hDoc += InventoryFormatter::createInventoryHtml(flags);
    }
 
-   //Render the Page onto the painter/printer for preview/printing.
+   // Render the page onto the painter/printer for preview/printing.
    textBrowser.setHtml(hDoc);
    textBrowser.print(printer);
 
