@@ -1,6 +1,7 @@
 /*
  * RefractoDialog.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2014
+ * authors 2009-2021
+ * - Matt Young <mfsy@yahoo.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -16,11 +17,9 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-#ifndef _REFRACTODIALOG_H
-#define _REFRACTODIALOG_H
-
-class RefractoDialog;
+#ifndef REFRACTODIALOG_H
+#define REFRACTODIALOG_H
+#pragma once
 
 #include <QDialog>
 #include <QWidget>
@@ -28,7 +27,6 @@ class RefractoDialog;
 
 /*!
  * \class RefractoDialog
- * \author Philip G. Lee
  *
  * \brief Dialog for calculating refractometer stuff.
  */
@@ -46,4 +44,4 @@ private:
    void clearOutputFields();
 };
 
-#endif /*_REFRACTODIALOG_H*/
+#endif
