@@ -1,6 +1,6 @@
 /*
  * StrikeWaterDialog.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Maxime Lavigne <duguigne@gmail.com>
  * - Philip G. Lee <rocketman768@gmail.com>
@@ -35,25 +35,25 @@
  *
  * \brief Dialog to calculate the amount and temperature of the strike water.
  */
-class StrikeWaterDialog : public QDialog, public Ui::strikeWaterDialog
-{
-  Q_OBJECT
-  public:
-    StrikeWaterDialog(QWidget* parent = 0);
-    ~StrikeWaterDialog();
+class StrikeWaterDialog : public QDialog, public Ui::strikeWaterDialog {
+   Q_OBJECT
+public:
+   StrikeWaterDialog(QWidget* parent = 0);
+   ~StrikeWaterDialog();
 
-  public slots:
-    void calculate();
+public slots:
+   void calculate();
 
-  private:
-    static const double specificHeatBarley;
+private:
+   /**
+    * \brief
+    */
+   double computeInitialInfusion();
 
-    double initialInfusionSi(double grainTemp, double targetTemp, double waterToGrain);
-    double mashInfusionSi(double initialTemp, double targetTemp,
-        double grainWeight, double infusionWater, double mashVolume);
-
-    double computeInitialInfusion();
-    double computeMashInfusion();
+   /**
+    * \brief
+    */
+   double computeMashInfusion();
 };
 
 #endif
