@@ -1,6 +1,6 @@
 /*
  * WaterDialog.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2022
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Maxime Lavigne <duguigne@gmail.com>
  * - Philip G. Lee <rocketman768@gmail.com>
@@ -27,7 +27,6 @@
 #include <QFont>
 #include <QInputDialog>
 
-#include "BtDigitWidget.h"
 #include "database/ObjectStoreWrapper.h"
 #include "measurement/ColorMethods.h"
 #include "model/Fermentable.h"
@@ -35,12 +34,14 @@
 #include "model/MashStep.h"
 #include "model/Recipe.h"
 #include "model/Salt.h"
+#include "tableModels/SaltTableModel.h"
+#include "tableModels/WaterTableModel.h"
 #include "WaterButton.h"
 #include "WaterEditor.h"
 #include "WaterListModel.h"
 #include "WaterSortFilterProxyModel.h"
-#include "tableModels/SaltTableModel.h"
-#include "tableModels/WaterTableModel.h"
+#include "widgets/SmartDigitWidget.h"
+
 
 //
 // All of the pH calculations are taken from the work done by Kai Troester and published at
@@ -69,19 +70,15 @@ namespace {
 
 WaterDialog::WaterDialog(QWidget* parent) :
    QDialog{parent},
-   m_ppm_digits{  QVector<BtDigitWidget*>{static_cast<int>(Water::Ions::numIons)} },
-   m_total_digits{QVector<BtDigitWidget*>{static_cast<int>(Salt::Types::numTypes)} },
+   m_ppm_digits{  QVector<SmartDigitWidget*>{static_cast<int>(Water::Ions::numIons)} },
+   m_total_digits{QVector<SmartDigitWidget*>{static_cast<int>(Salt::Types::numTypes)} },
    m_rec{nullptr},
    m_base{nullptr},
    m_target{nullptr},
    m_mashRO{0.0},
    m_spargeRO{0.0},
    m_total_grains{0.0},
-   m_thickness{0.0}
-{
-   QStringList msgs = QStringList() << tr("Too low for target profile.")
-                                    << tr("In range for target profile.")
-                                    << tr("Too high for target profile.");
+   m_thickness{0.0} {
 
    setupUi(this);
    // initialize the two buttons and lists (I think)
@@ -101,36 +98,53 @@ WaterDialog::WaterDialog(QWidget* parent) :
    m_target_filter->sort(0);
    targetProfileCombo->setModel(m_target_filter);
 
-   // not sure if this is better or worse, but we will try it out
-   m_ppm_digits[static_cast<int>(Water::Ions::Ca)]   = btDigit_ca;
-   m_ppm_digits[static_cast<int>(Water::Ions::Cl)]   = btDigit_cl;
-   m_ppm_digits[static_cast<int>(Water::Ions::HCO3)] = btDigit_hco3;
-   m_ppm_digits[static_cast<int>(Water::Ions::Mg)]   = btDigit_mg;
-   m_ppm_digits[static_cast<int>(Water::Ions::Na)]   = btDigit_na;
-   m_ppm_digits[static_cast<int>(Water::Ions::SO4)]  = btDigit_so4;
+   SMART_FIELD_INIT_FS(WaterDialog, label_ca  , btDigit_ca  , double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_cl  , btDigit_cl  , double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_hco3, btDigit_hco3, double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_mg  , btDigit_mg  , double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_na  , btDigit_na  , double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_so4 , btDigit_so4 , double, Measurement::PhysicalQuantity::VolumeConcentration, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_pH  , btDigit_ph  , double, Measurement::PhysicalQuantity::Acidity            , 1);
 
-   m_total_digits[static_cast<int>(Salt::Types::CACL2 )] = btDigit_totalcacl2;
-   m_total_digits[static_cast<int>(Salt::Types::CACO3 )] = btDigit_totalcaco3;
-   m_total_digits[static_cast<int>(Salt::Types::CASO4 )] = btDigit_totalcaso4;
-   m_total_digits[static_cast<int>(Salt::Types::MGSO4 )] = btDigit_totalmgso4;
-   m_total_digits[static_cast<int>(Salt::Types::NACL  )] = btDigit_totalnacl;
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalcacl2 , btDigit_totalcacl2 , double, Measurement::PhysicalQuantity::Mass, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalcaco3 , btDigit_totalcaco3 , double, Measurement::PhysicalQuantity::Mass, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalcaso4 , btDigit_totalcaso4 , double, Measurement::PhysicalQuantity::Mass, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalmgso4 , btDigit_totalmgso4 , double, Measurement::PhysicalQuantity::Mass, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalnacl  , btDigit_totalnacl  , double, Measurement::PhysicalQuantity::Mass, 2);
+   SMART_FIELD_INIT_FS(WaterDialog, label_totalnahco3, btDigit_totalnahco3, double, Measurement::PhysicalQuantity::Mass, 2);
+
+   // not sure if this is better or worse, but we will try it out
+   m_ppm_digits[static_cast<int>(Water::Ions::Ca)]   = btDigit_ca  ;
+   m_ppm_digits[static_cast<int>(Water::Ions::Cl)]   = btDigit_cl  ;
+   m_ppm_digits[static_cast<int>(Water::Ions::HCO3)] = btDigit_hco3;
+   m_ppm_digits[static_cast<int>(Water::Ions::Mg)]   = btDigit_mg  ;
+   m_ppm_digits[static_cast<int>(Water::Ions::Na)]   = btDigit_na  ;
+   m_ppm_digits[static_cast<int>(Water::Ions::SO4)]  = btDigit_so4 ;
+
+   m_total_digits[static_cast<int>(Salt::Types::CACL2 )] = btDigit_totalcacl2 ;
+   m_total_digits[static_cast<int>(Salt::Types::CACO3 )] = btDigit_totalcaco3 ;
+   m_total_digits[static_cast<int>(Salt::Types::CASO4 )] = btDigit_totalcaso4 ;
+   m_total_digits[static_cast<int>(Salt::Types::MGSO4 )] = btDigit_totalmgso4 ;
+   m_total_digits[static_cast<int>(Salt::Types::NACL  )] = btDigit_totalnacl  ;
    m_total_digits[static_cast<int>(Salt::Types::NAHCO3)] = btDigit_totalnahco3;
 
-   // foreach( BtDigitWidget* i, m_ppm_digits ) {
-   for(int i = 0; i < static_cast<int>(Water::Ions::numIons); ++i ) {
+   // foreach( SmartDigitWidget* i, m_ppm_digits ) {
+   for (int i = 0; i < static_cast<int>(Water::Ions::numIons); ++i ) {
       m_ppm_digits[i]->setLimits(0.0,1000.0);
-      m_ppm_digits[i]->setText(0.0, 1);
-      m_ppm_digits[i]->setMessages(msgs);
+      m_ppm_digits[i]->setAmount(0.0);
+      m_ppm_digits[i]->setMessages(tr("Too low for target profile."),
+                                   tr("In range for target profile."),
+                                   tr("Too high for target profile."));
    }
    // we can be a bit more specific with pH
    btDigit_ph->setLowLim(5.0);
    btDigit_ph->setHighLim(5.5);
-   btDigit_ph->display(7.0,1);
+   btDigit_ph->setAmount(7.0);
 
    // since all the things are now digits, lets get the totals configured
    for (int i = static_cast<int>(Salt::Types::CACL2); i < static_cast<int>(Salt::Types::NAHCO3); ++i ) {
-      m_total_digits[i]->setConstantColor(BtDigitWidget::BLACK);
-      m_total_digits[i]->setText(0.0,1);
+      m_total_digits[i]->setConstantColor(SmartDigitWidget::ColorType::Black);
+      m_total_digits[i]->setAmount(0.0);
    }
    // and now let's see what the table does.
    m_salt_table_model = new SaltTableModel(tableView_salts);
@@ -138,24 +152,24 @@ WaterDialog::WaterDialog(QWidget* parent) :
    tableView_salts->setItemDelegate(m_salt_delegate);
    tableView_salts->setModel(m_salt_table_model);
 
-   m_base_editor = new WaterEditor(this, "Base");
+   m_base_editor   = new WaterEditor(this, "Base");
    m_target_editor = new WaterEditor(this, "Target");
 
    // all the signals
-   connect(baseProfileCombo,   SIGNAL( activated(int)), this, SLOT(update_baseProfile(int)));
-   connect(targetProfileCombo, SIGNAL( activated(int)), this, SLOT(update_targetProfile(int)));
+   connect(baseProfileCombo,   QOverload<int>::of(&QComboBox::activated), this, &WaterDialog::update_baseProfile  );
+   connect(targetProfileCombo, QOverload<int>::of(&QComboBox::activated), this, &WaterDialog::update_targetProfile);
 
    connect(baseProfileButton,   &WaterButton::clicked, m_base_editor,   &QWidget::show);
    connect(targetProfileButton, &WaterButton::clicked, m_target_editor, &QWidget::show);
 
-   connect(m_salt_table_model,    &SaltTableModel::newTotals, this, &WaterDialog::newTotals);
+   connect(m_salt_table_model,    &SaltTableModel::newTotals, this,               &WaterDialog::newTotals   );
    connect(pushButton_addSalt,    &QAbstractButton::clicked,  m_salt_table_model, &SaltTableModel::catchSalt);
-   connect(pushButton_removeSalt, &QAbstractButton::clicked,  this, &WaterDialog::removeSalts);
+   connect(pushButton_removeSalt, &QAbstractButton::clicked,  this,               &WaterDialog::removeSalts );
 
-   connect(spinBox_mashRO, SIGNAL(valueChanged(int)),   this, SLOT(setMashRO(int)));
-   connect(spinBox_spargeRO, SIGNAL(valueChanged(int)), this, SLOT(setSpargeRO(int)));
+   connect(spinBox_mashRO,   QOverload<int>::of(&QSpinBox::valueChanged), this, &WaterDialog::setMashRO  );
+   connect(spinBox_spargeRO, QOverload<int>::of(&QSpinBox::valueChanged), this, &WaterDialog::setSpargeRO);
 
-   connect(buttonBox_save, &QDialogButtonBox::accepted, this, &WaterDialog::saveAndClose);
+   connect(buttonBox_save, &QDialogButtonBox::accepted, this, &WaterDialog::saveAndClose );
    connect(buttonBox_save, &QDialogButtonBox::rejected, this, &WaterDialog::clearAndClose);
 
    return;
@@ -167,12 +181,14 @@ void WaterDialog::setMashRO(int val) {
    m_mashRO = val/100.0;
    if ( m_base ) m_base->setMashRO(m_mashRO);
    newTotals();
+   return;
 }
 
 void WaterDialog::setSpargeRO(int val) {
    m_spargeRO = val/100.0;
    if ( m_base ) m_base->setSpargeRO(m_spargeRO);
    newTotals();
+   return;
 }
 
 void WaterDialog::setDigits() {
@@ -184,12 +200,10 @@ void WaterDialog::setDigits() {
       double ppm = this->m_target->ppm(static_cast<Water::Ions>(i));
       double min_ppm = ppm * 0.95;
       double max_ppm = ppm * 1.05;
-      QStringList msgs = QStringList()
-         << tr("Minimum expected concentration is %1 ppm").arg(min_ppm)
-         << tr("In range for target profile.")
-         << tr("Maximum expected concentration is %1 ppm").arg(max_ppm);
       m_ppm_digits[i]->setLimits(min_ppm,max_ppm);
-      m_ppm_digits[i]->setMessages(msgs);
+      m_ppm_digits[i]->setMessages(tr("Minimum expected concentration is %1 ppm").arg(min_ppm),
+                                   tr("In range for target profile."),
+                                   tr("Maximum expected concentration is %1 ppm").arg(max_ppm));
    }
 
    // oddly, pH doesn't change with the target water
@@ -197,7 +211,7 @@ void WaterDialog::setDigits() {
 }
 
 void WaterDialog::setRecipe(Recipe *rec) {
-   if ( rec == nullptr ) {
+   if (!rec) {
       return;
    }
 
@@ -325,7 +339,7 @@ void WaterDialog::newTotals() {
 
    for (int i = static_cast<int>(Salt::Types::CACL2); i < static_cast<int>(Salt::Types::LACTIC); ++i ) {
       Salt::Types type = static_cast<Salt::Types>(i);
-      m_total_digits[i]->setText(m_salt_table_model->total(type), 2);
+      m_total_digits[i]->setAmount(m_salt_table_model->total(type));
    }
 
    // the total_* method return the numerator, we supply the denominator and
@@ -343,17 +357,18 @@ void WaterDialog::newTotals() {
       for (int i = 0; i < static_cast<int>(Water::Ions::numIons); ++i ) {
          Water::Ions ion = static_cast<Water::Ions>(i);
          double mPPM = modifier * this->m_base->ppm(ion);
-         m_ppm_digits[i]->setText( m_salt_table_model->total(ion) / allTheWaters + mPPM, 0 );
+         m_ppm_digits[i]->setAmount( m_salt_table_model->total(ion) / allTheWaters + mPPM);
 
       }
-      btDigit_ph->setText( calculateMashpH(), 2 );
+      btDigit_ph->setAmount(calculateMashpH());
 
    } else {
       for (int i = 0; i < static_cast<int>(Water::Ions::numIons); ++i ) {
          Water::Ions ion = static_cast<Water::Ions>(i);
-         m_ppm_digits[i]->setText( m_salt_table_model->total(ion) / allTheWaters, 0 );
+         m_ppm_digits[i]->setAmount( m_salt_table_model->total(ion) / allTheWaters);
       }
    }
+   return;
 }
 
 void WaterDialog::removeSalts() {
@@ -456,22 +471,22 @@ double WaterDialog::calculateGristpH() {
 
    if ( m_rec && m_rec->fermentables().size() ) {
 
-      double platoRatio = 1/Measurement::Units::plato.fromSI(m_rec->og());
+      double platoRatio = 1/Measurement::Units::plato.fromCanonical(m_rec->og());
       double color = m_rec->color_srm();
       double colorFromGrain = 0.0;
 
       for (Fermentable * i : m_rec->fermentables()) {
-         // I am counting anything that doesn't have diastatic
-         // power as a roasted/crystal malt. I am sure my assumption will
-         // haunt me later, but I have no way of knowing what kind of malt
-         // (base, crystal, roasted) this is.
+               // I am counting anything that doesn't have diastatic
+               // power as a roasted/crystal malt. I am sure my assumption will
+               // haunt me later, but I have no way of knowing what kind of malt
+               // (base, crystal, roasted) this is.
          if ( i->diastaticPower_lintner() < 1 ) {
-            double lovi = 19.0;
+                  double lovi = 19.0;
             if ( i->color_srm() <= 120 ) {
                lovi = ( i->color_srm() + 0.6)/1.35;
-            }
+               }
             colorFromGrain = ( i->amount_kg() / m_total_grains ) * lovi;
-          }
+         }
       }
       double colorRatio = colorFromGrain/m_weighted_colors;
       pHAdjustment = platoRatio * ( pHSlopeLight * (1-colorRatio) + pHSlopeDark * colorRatio) *color;
