@@ -1,6 +1,6 @@
 /*
  * database/ObjectStoreTyped.h is part of Brewtarget, and is copyright the
- * following authors 2021-2022:
+ * following authors 2021-2023:
  *   • Matt Young <mfsy@yahoo.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -39,9 +39,10 @@ public:
     *
     * \param primaryTable First in the list of fields in this table defn should be the primary key
     */
-   ObjectStoreTyped(TableDefinition const & primaryTable,
+   ObjectStoreTyped(TypeLookup               const & typeLookup,
+                    TableDefinition          const & primaryTable,
                     JunctionTableDefinitions const & junctionTables = JunctionTableDefinitions{}) :
-      ObjectStore(primaryTable, junctionTables) {
+      ObjectStore(typeLookup, primaryTable, junctionTables) {
       return;
    }
 
@@ -54,6 +55,8 @@ public:
     */
    static ObjectStoreTyped<NE> & getInstance();
 
+   using ObjectStore::insert;
+
    /**
     * \brief Insert a new object in the DB (and in our cache list)
     */
@@ -105,6 +108,8 @@ public:
       return this->insert(nePointer);
    }
 
+   using ObjectStore::insertOrUpdate;
+
    /**
     * \brief Convenience function that calls either \c insert or \c update, depending on whether the object is already
     *        stored.
@@ -241,7 +246,8 @@ public:
    /**
     * \brief Search the set of all cached objects with a lambda.
     *
-    * \param matchFunction Takes a pointer to an object and returns \c true if the object is a match or \c false otherwise.
+    * \param matchFunction Takes a pointer to an object and returns \c true if the object is a match or \c false
+    *                      otherwise.
     *
     * \return List of shared pointers to all the objects that give a \c true result to \c matchFunction (and thus an
     *         empty list if none does).
@@ -378,9 +384,12 @@ private:
 
    //! No copy constructor, as never want anyone, not even our friends, to make copies of a singleton
    ObjectStoreTyped(ObjectStoreTyped const &) = delete;
-   //! No assignment operator , as never want anyone, not even our friends, to make copies of a singleton.
+   //! No copy assignment operator, as never want anyone, not even our friends, to make copies of a singleton.
    ObjectStoreTyped & operator=(ObjectStoreTyped const &) = delete;
-
+   //! No move constructor
+   ObjectStoreTyped(ObjectStoreTyped && other) = delete;
+   //! No move assignment operator
+   ObjectStoreTyped& operator=(ObjectStoreTyped&& other) = delete;
 };
 
 /**
