@@ -1,6 +1,6 @@
 /*
  * model/Mash.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
@@ -83,17 +83,50 @@ ObjectStore & Mash::getObjectStoreTypedInstance() const {
    return ObjectStoreTyped<Mash>::getInstance();
 }
 
+TypeLookup const Mash::typeLookup {
+   "Mash",
+   {
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::equipAdjust          , Mash::m_equipAdjust          ,           NonPhysicalQuantity::Bool                ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::grainTemp_c          , Mash::m_grainTemp_c          , Measurement::PhysicalQuantity::Temperature         ),
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::mashSteps            , Mash::m_mashSteps            ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::notes                , Mash::m_notes                ,           NonPhysicalQuantity::String              ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::ph                   , Mash::m_ph                   , Measurement::PhysicalQuantity::Acidity             ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::spargeTemp_c         , Mash::m_spargeTemp_c         , Measurement::PhysicalQuantity::Temperature         ),
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::totalMashWater_l     , Mash::m_totalMashWater_l     ), // Calculated, not stored
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::totalTime            , Mash::m_totalTime            ), // Calculated, not stored
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::tunSpecificHeat_calGC, Mash::m_tunSpecificHeat_calGC, Measurement::PhysicalQuantity::SpecificHeatCapacity),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::tunTemp_c            , Mash::m_tunTemp_c            , Measurement::PhysicalQuantity::Temperature         ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Mash::tunWeight_kg         , Mash::m_tunWeight_kg         , Measurement::PhysicalQuantity::Mass                ),
+   },
+   // Parent class lookup
+   &NamedEntity::typeLookup
+};
+
 Mash::Mash(QString name) :
    NamedEntity{name, true},
    pimpl{std::make_unique<impl>(*this)},
-   m_grainTemp_c(0.0),
-   m_notes(QString()),
-   m_tunTemp_c(0.0),
-   m_spargeTemp_c(0.0),
-   m_ph(0.0),
-   m_tunWeight_kg(0.0),
-   m_tunSpecificHeat_calGC(0.0),
-   m_equipAdjust(true) {
+   m_grainTemp_c          {0.0 },
+   m_notes                {""  },
+   m_tunTemp_c            {0.0 },
+   m_spargeTemp_c         {0.0 },
+   m_ph                   {0.0 },
+   m_tunWeight_kg         {0.0 },
+   m_tunSpecificHeat_calGC{0.0 },
+   m_equipAdjust          {true} {
+   return;
+}
+
+Mash::Mash(NamedParameterBundle const & namedParameterBundle) :
+   NamedEntity            {namedParameterBundle},
+   pimpl{std::make_unique<impl>(*this)},
+   m_grainTemp_c          {namedParameterBundle.val<double >(PropertyNames::Mash::grainTemp_c          )},
+   m_notes                {namedParameterBundle.val<QString>(PropertyNames::Mash::notes                )},
+   m_tunTemp_c            {namedParameterBundle.val<double >(PropertyNames::Mash::tunTemp_c            )},
+   m_spargeTemp_c         {namedParameterBundle.val<double >(PropertyNames::Mash::spargeTemp_c         )},
+   m_ph                   {namedParameterBundle.val<double >(PropertyNames::Mash::ph                   )},
+   m_tunWeight_kg         {namedParameterBundle.val<double >(PropertyNames::Mash::tunWeight_kg         )},
+   m_tunSpecificHeat_calGC{namedParameterBundle.val<double >(PropertyNames::Mash::tunSpecificHeat_calGC)},
+   m_equipAdjust          {namedParameterBundle.val<bool   >(PropertyNames::Mash::equipAdjust          )} {
    return;
 }
 
@@ -134,21 +167,6 @@ Mash::Mash(Mash const & other) :
    return;
 }
 
-
-Mash::Mash(NamedParameterBundle const & namedParameterBundle) :
-   NamedEntity            {namedParameterBundle},
-   pimpl{std::make_unique<impl>(*this)},
-   m_grainTemp_c          {namedParameterBundle(PropertyNames::Mash::grainTemp_c          ).toDouble()},
-   m_notes                {namedParameterBundle(PropertyNames::Mash::notes                ).toString()},
-   m_tunTemp_c            {namedParameterBundle(PropertyNames::Mash::tunTemp_c            ).toDouble()},
-   m_spargeTemp_c         {namedParameterBundle(PropertyNames::Mash::spargeTemp_c         ).toDouble()},
-   m_ph                   {namedParameterBundle(PropertyNames::Mash::ph                   ).toDouble()},
-   m_tunWeight_kg         {namedParameterBundle(PropertyNames::Mash::tunWeight_kg         ).toDouble()},
-   m_tunSpecificHeat_calGC{namedParameterBundle(PropertyNames::Mash::tunSpecificHeat_calGC).toDouble()},
-   m_equipAdjust          {namedParameterBundle(PropertyNames::Mash::equipAdjust          ).toBool()} {
-   return;
-}
-
 // See https://herbsutter.com/gotw/_100/ for why we need to explicitly define the destructor here (and not in the
 // header file)
 Mash::~Mash() = default;
@@ -361,7 +379,8 @@ QList< std::shared_ptr<MashStep> > Mash::mashSteps() const {
    return mashSteps;
 }
 
-void Mash::acceptMashStepChange(QMetaProperty prop, QVariant /*val*/) {
+void Mash::acceptMashStepChange([[maybe_unused]] QMetaProperty prop,
+                                [[maybe_unused]] QVariant      val) {
    MashStep* stepSender = qobject_cast<MashStep*>(sender());
    if (stepSender == nullptr) {
       return;
