@@ -1,6 +1,6 @@
 /*
  * model/Misc.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
@@ -58,7 +58,51 @@ ObjectStore & Misc::getObjectStoreTypedInstance() const {
    return ObjectStoreTyped<Misc>::getInstance();
 }
 
+TypeLookup const Misc::typeLookup {
+   "Misc",
+   {
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::amount        , Misc::m_amount        , Measurement::PqEitherMassOrVolume),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::amountIsWeight, Misc::m_amountIsWeight),
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::amountType    , Misc::m_amountType    ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::notes         , Misc::m_notes         ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::time          , Misc::m_time          , Measurement::PhysicalQuantity::Time),
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::typeString    , Misc::m_typeString    ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::type          , Misc::m_type          ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::useFor        , Misc::m_useFor        ),
+//      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::useString     , Misc::m_useString     ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::Misc::use           , Misc::m_use           ),
+   },
+   // Parent class lookup.  NB: NamedEntityWithInventory not NamedEntity!
+   &NamedEntityWithInventory::typeLookup
+};
+static_assert(std::is_base_of<NamedEntityWithInventory, Misc>::value);
+
 //============================CONSTRUCTORS======================================
+
+Misc::Misc(QString name) :
+   NamedEntityWithInventory{name, true},
+   m_type          {Misc::Type::Spice},
+   m_use           {Misc::Use::Boil  },
+   m_time          {0.0              },
+   m_amount        {0.0              },
+   m_amountIsWeight{false            },
+   m_useFor        {""               },
+   m_notes         {""               } {
+   return;
+}
+
+Misc::Misc(NamedParameterBundle const & namedParameterBundle) :
+   NamedEntityWithInventory{namedParameterBundle},
+   m_type                  {namedParameterBundle.val<Misc::Type>(PropertyNames::Misc::type          )},
+   m_use                   {namedParameterBundle.val<Misc::Use >(PropertyNames::Misc::use           )},
+   m_time                  {namedParameterBundle.val<double    >(PropertyNames::Misc::time          )},
+   m_amount                {namedParameterBundle.val<double    >(PropertyNames::Misc::amount        )},
+   m_amountIsWeight        {namedParameterBundle.val<bool      >(PropertyNames::Misc::amountIsWeight)},
+   m_useFor                {namedParameterBundle.val<QString   >(PropertyNames::Misc::useFor        )},
+   m_notes                 {namedParameterBundle.val<QString   >(PropertyNames::Misc::notes         )} {
+   return;
+}
+
 Misc::Misc(Misc const & other) :
    NamedEntityWithInventory{other                 },
    m_type                  {other.m_type          },
@@ -71,30 +115,7 @@ Misc::Misc(Misc const & other) :
    return;
 }
 
-Misc::Misc(QString name) :
-   NamedEntityWithInventory{name, true},
-   m_type                  {Misc::Type::Spice},
-   m_use                   {Misc::Use::Boil },
-   m_time                  {0.0        },
-   m_amount                {0.0        },
-   m_amountIsWeight        {false      },
-   m_useFor                {""         },
-   m_notes                 {""         } {
-   return;
-}
-
-Misc::Misc(NamedParameterBundle const & namedParameterBundle) :
-   NamedEntityWithInventory{namedParameterBundle},
-   m_type                  {static_cast<Misc::Type>(namedParameterBundle(PropertyNames::Misc::type).toInt())},
-   m_use                   {static_cast<Misc::Use>(namedParameterBundle(PropertyNames::Misc::use).toInt())},
-   m_time                  {namedParameterBundle(PropertyNames::Misc::time          ).toDouble()},
-   m_amount                {namedParameterBundle(PropertyNames::Misc::amount        ).toDouble()},
-   m_amountIsWeight        {namedParameterBundle(PropertyNames::Misc::amountIsWeight).toBool()},
-   m_useFor                {namedParameterBundle(PropertyNames::Misc::useFor        ).toString()},
-   m_notes                 {namedParameterBundle(PropertyNames::Misc::notes         ).toString()} {
-   return;
-}
-
+Misc::~Misc() = default;
 
 //============================"GET" METHODS=====================================
 Misc::Type Misc::type() const { return m_type; }
