@@ -1,6 +1,6 @@
 /*
  * model/NamedEntity.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2022
+ * authors 2009-2023
  * - Kregg K <gigatropolis@yahoo.com>
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
@@ -32,26 +32,14 @@
 #include "model/Recipe.h"
 
 NamedEntity::NamedEntity(QString t_name, bool t_display, QString folder) :
-   QObject    {nullptr  },
-   m_key      {-1       },
-   parentKey  {-1       },
-   m_folder   {folder   },
-   m_name     {t_name   },
-   m_display  {t_display},
-   m_deleted  {false    },
-   m_beingModified{false} {
-   return;
-}
-
-NamedEntity::NamedEntity(NamedEntity const & other) :
-   QObject     {nullptr          }, // QObject doesn't have a copy constructor, so just make a new one
-   m_key       {-1               }, // We don't want to copy the other object's key/ID
-   parentKey   {other.parentKey  },
-   m_folder    {other.m_folder   },
-   m_name      {other.m_name     },
-   m_display   {other.m_display  },
-   m_deleted   {other.m_deleted  },
-   m_beingModified{false} {
+   QObject        {nullptr  },
+   m_key          {-1       },
+   parentKey      {-1       },
+   m_folder       {folder   },
+   m_name         {t_name   },
+   m_display      {t_display},
+   m_deleted      {false    },
+   m_beingModified{false    } {
    return;
 }
 
@@ -70,13 +58,25 @@ NamedEntity::NamedEntity(NamedEntity const & other) :
 //         future.
 //
 NamedEntity::NamedEntity(NamedParameterBundle const & namedParameterBundle) :
-   QObject{nullptr},
-   m_key      {namedParameterBundle(PropertyNames::NamedEntity::key, -1)          },
-   parentKey  {namedParameterBundle(PropertyNames::NamedEntity::parentKey, -1)    },
-   m_folder   {namedParameterBundle(PropertyNames::NamedEntity::folder, QString{})},
-   m_name     {namedParameterBundle(PropertyNames::NamedEntity::name, QString{})  },
-   m_display  {namedParameterBundle(PropertyNames::NamedEntity::display, true)    },
-   m_deleted  {namedParameterBundle(PropertyNames::NamedEntity::deleted, false)   },
+   QObject        {nullptr},
+   m_key          {namedParameterBundle.val(PropertyNames::NamedEntity::key,       -1       )},
+   parentKey      {namedParameterBundle.val(PropertyNames::NamedEntity::parentKey, -1       )},
+   m_folder       {namedParameterBundle.val(PropertyNames::NamedEntity::folder,    QString{})},
+   m_name         {namedParameterBundle.val(PropertyNames::NamedEntity::name,      QString{})},
+   m_display      {namedParameterBundle.val(PropertyNames::NamedEntity::display,   true     )},
+   m_deleted      {namedParameterBundle.val(PropertyNames::NamedEntity::deleted,   false    )},
+   m_beingModified{false} {
+   return;
+}
+
+NamedEntity::NamedEntity(NamedEntity const & other) :
+   QObject     {nullptr        }, // QObject doesn't have a copy constructor, so just make a new one
+   m_key       {-1             }, // We don't want to copy the other object's key/ID
+   parentKey   {other.parentKey},
+   m_folder    {other.m_folder },
+   m_name      {other.m_name   },
+   m_display   {other.m_display},
+   m_deleted   {other.m_deleted},
    m_beingModified{false} {
    return;
 }
@@ -99,6 +99,24 @@ void NamedEntity::swap(NamedEntity & other) noexcept {
    return;
 }
 
+TypeLookup const NamedEntity::typeLookup {
+   "NamedEntity",
+   {
+      // As long as we map each property name to its corresponding member variable, the compiler should be able to work
+      // everything else out.  The only exception is that, for enums, we have to pretend they are stored as int, because
+      // that's what's going to come out of the Qt property system (and it would significantly complicate other bits of
+      // the code to separately register every different enum that we use.)
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::deleted  , NamedEntity::m_deleted                             ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::display  , NamedEntity::m_display                             ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::folder   , NamedEntity::m_folder                              ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::key      , NamedEntity::m_key                                 ),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::name     , NamedEntity::m_name   , NonPhysicalQuantity::String),
+      PROPERTY_TYPE_LOOKUP_ENTRY(PropertyNames::NamedEntity::parentKey, NamedEntity::parentKey                             ),
+   },
+   // Parent class lookup - none as we're top of the tree
+   nullptr
+};
+
 NamedEntity::~NamedEntity() = default;
 
 void NamedEntity::makeChild(NamedEntity const & copiedFrom) {
