@@ -1,6 +1,6 @@
 /*
  * tableModels/BtTableModel.h is part of Brewtarget, and is copyright the following
- * authors 2021-2022:
+ * authors 2021-2023:
  * - Matt Young <mfsy@yahoo.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #pragma once
 
 #include <optional>
+#include <vector>
 
 #include <QAbstractTableModel>
 #include <QDebug>
@@ -41,9 +42,9 @@ class Recipe;
  *
  * \brief Unfortunately we can't template \c BtTableModel because it inherits from a \c QObject and the Qt meta-object
  *        compiler (moc) can't handle templated classes in QObject-derived classes (though it is fine with templated
- *        member functions in such classes, as long as the are not signals or slots).  We might one day look at
+ *        member functions in such classes, as long as they are not signals or slots).  We might one day look at
  *        https://github.com/woboq/verdigris, which overcomes these limitations, but, for now, we live within Qt's
- *        limitations and try to pull out as much common code as possible using a limited form of multiple inheritance.
+ *        constraints and try to pull out as much common code as possible using a limited form of multiple inheritance.
  *
  *              QObject
  *                   \
@@ -52,7 +53,7 @@ class Recipe;
  *              QAbstractTableModel
  *                           \
  *                            \
- *                          BtTableModel               BtTableModelData
+ *                          BtTableModel               BtTableModelData<NE>
  *                                /   \                /     /     /
  *                               /     \              /     /     /
  *                              /      MashStepTableModel  /     /
@@ -129,7 +130,7 @@ public:
 
       for (auto ii : items) {
          if (!recipe && ii->deleted() ) {
-               continue;
+            continue;
          }
          if (!this->rows.contains(ii) ) {
             tmp.append(ii);
@@ -137,6 +138,7 @@ public:
       }
       return tmp;
    }
+
    /**
     * \brief Given a raw pointer, find the index of the corresponding shared pointer in \c this->rows
     *
@@ -179,27 +181,77 @@ protected:
 class BtTableModel : public QAbstractTableModel {
    Q_OBJECT
 public:
+   /**
+    * \brief This per-column struct / mini-class holds basic info about each column in the table.  It also plays a
+    *        slightly similar role as \c SmartLabel.  However, there are several important differences, including that
+    *        \c ColumnInfo is \b not a \c QWidget and therefore not a signal emitter.  (As mentioned below, it is
+    *        \c QHeaderView that sends us the signal about the user having right-clicked on a column header.  We then
+    *        act on the pop-up menu selections directly, rather than \c SmartLabel sending a signal that
+    *        \c SmartLineEdit (and sometimes others) pick up.
+    *
+    *        NOTE that you usually want to use the SMART_COLUMN_HEADER_INIT macro when constructing
+    */
    struct ColumnInfo {
-      QString headerName;
-      BtFieldType fieldType;
-      QString attribute;
+      /**
+       * \brief By analogy with \c editorName in \c SmartLabel and \c SmartLineEdit
+       */
+      char const * const tableModelName;
+
+      /**
+       * \brief By analogy with \c labelName in \c SmartLabel and \c lineEditName in \c SmartLineEdit
+       */
+      char const * const columnName;
+
+      /**
+       * \brief By analogy with \c labelFqName in \c SmartLabel and \c lineEditFqName in \c SmartLineEdit
+       */
+      char const * const columnFqName;
+
+      /**
+       * \brief Each subclass should normally declare its own \c enum \c class \c ColumnIndex to identify its columns.
+       *        We store the column index here as a cross-check that we've got everything in the right order.
+       */
+      size_t const index;
+
+      /**
+       * \brief The localised text to display in this column header
+       */
+      QString const label;
+      /**
+       * \brief What type of data is shown in this column
+       */
+      BtFieldType const fieldType;
+
+      /**
+       *
+       */
+      std::optional<unsigned int> const precision = std::nullopt;
+
+      // Stuff for setting display units and scales -- per column
+      // I know it looks odd to have const setters, but they are const because they do not change the data in the struct
+      void setForcedSystemOfMeasurement(std::optional<Measurement::SystemOfMeasurement> forcedSystemOfMeasurement) const;
+      void setForcedRelativeScale(std::optional<Measurement::UnitSystem::RelativeScale> forcedScale) const;
+      std::optional<Measurement::SystemOfMeasurement> getForcedSystemOfMeasurement() const;
+      std::optional<Measurement::UnitSystem::RelativeScale> getForcedRelativeScale() const;
+
    };
 
+   /**
+    * \brief
+    *
+    * \param parent
+    * \param editable
+    * \param columnInfos Needs to be in order
+    */
    BtTableModel(QTableView * parent,
                 bool editable,
-                std::initializer_list<std::pair<int const, ColumnInfo> > columnIdToInfo);
+                std::initializer_list<ColumnInfo> columnInfos);
    virtual ~BtTableModel();
 
-   // Stuff for setting display units and scales -- per cell column
-   std::optional<Measurement::SystemOfMeasurement> getForcedSystemOfMeasurementForColumn(int column) const;
-   std::optional<Measurement::UnitSystem::RelativeScale> getForcedRelativeScaleForColumn(int column) const;
-   void setForcedSystemOfMeasurementForColumn(int column,
-                                              std::optional<Measurement::SystemOfMeasurement> systemOfMeasurement);
-   void setForcedRelativeScaleForColumn(int column,
-                                        std::optional<Measurement::UnitSystem::RelativeScale> relativeScale);
+   ColumnInfo const & getColumnInfo(size_t const columnIndex) const;
 
    //! \brief Called from \c headerData()
-   QVariant getColumName(int column) const;
+   QVariant getColumnLabel(size_t const columnIndex) const;
 
    // Per https://doc.qt.io/qt-5/qabstracttablemodel.html, when subclassing QAbstractTableModel, you must implement
    // rowCount(), columnCount(), and data(). Default implementations of the index() and parent() functions are provided
@@ -209,30 +261,39 @@ public:
    virtual int columnCount(QModelIndex const & parent = QModelIndex()) const;
 
 private:
-   QString     columnGetAttribute(int column) const;
-   BtFieldType columnGetFieldType(int column) const;
    void doContextMenu(QPoint const & point, QHeaderView * hView, QMenu * menu, int selected);
 
 public slots:
-   //! \brief pops the context menu for changing units and scales
+   //! \brief Receives the \c QWidget::customContextMenuRequested signal from \c QHeaderView to pops the context menu
+   // for changing units and scales
    void contextMenu(QPoint const & point);
 
 protected:
    QTableView* parentTableWidget;
    bool editable;
 private:
-   QMap<int, ColumnInfo> columnIdToInfo;
-
+   /**
+    * \brief The order of
+    */
+   std::vector<ColumnInfo> const m_columnInfos;
 };
 
 class BtTableModelRecipeObserver : public BtTableModel {
 public:
    BtTableModelRecipeObserver(QTableView * parent,
                               bool editable,
-                              std::initializer_list<std::pair<int const, ColumnInfo> > columnIdToInfo);
+                              std::initializer_list<ColumnInfo> columnInfos);
    ~BtTableModelRecipeObserver();
 
 protected:
    Recipe* recObs;
 };
+
+#define SMART_COLUMN_HEADER_DEFN(tableModelClass, columnName, labelText, btFieldType, ...) \
+   BtTableModel::ColumnInfo{#tableModelClass, \
+                            #columnName, \
+                            #tableModelClass "::ColumnIndex::" #columnName, \
+                            static_cast<size_t>(tableModelClass::ColumnIndex::columnName), \
+                            labelText, \
+                            btFieldType}
 #endif
