@@ -1,6 +1,6 @@
 /*
  * FermentableTableModel.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2022
+ * authors 2009-2023
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
  * - Philip Greggory Lee <rocketman768@gmail.com>
@@ -22,6 +22,8 @@
  */
 #include "tableModels/FermentableTableModel.h"
 
+#include <array>
+
 #include <QAbstractItemModel>
 #include <QAbstractItemView>
 #include <QAbstractTableModel>
@@ -49,19 +51,50 @@
 #include "PersistentSettings.h"
 #include "utils/BtStringConst.h"
 
+namespace {
+   //
+   // We have a bunch of logic for interpreting Fermentable::isMashed() and Fermentable::addAfterBoil() which used to
+   // live in the Fermentable class itself but is only used in this table model, so I moved it here to simplify
+   // Fermentable.
+   //
+   // Additionally, we used to assume that a thing that is a grain and not mashed must be steeped.  This is not
+   // necessarily true.  I have simplified things so we now just show two options - Mashed and Not Mashed.
+   //
+   // Note that these two arrays rely on the fact that static_cast<int>(false) == 0 and static_cast<int>(true) == 1
+   //
+   std::array<QString const, 2> descAddAfterBoil {
+      QObject::tr("Normal"), // addAfterBoil() == false
+      QObject::tr("Late")    // addAfterBoil() == true
+   };
+   std::array<QString const, 2> descIsMashed {
+      QObject::tr("Not mashed"), // isMashed() == false
+      QObject::tr("Mashed")      // isMashed() == true
+   };
+   std::array<QString const, 2> descAmountIsWeight {
+      QObject::tr("Volume"), // amountIsWeight() == false
+      QObject::tr("Weight")      // amountIsWeight() == true
+   };
+
+}
+
+// .:TODO:. We need to unify some of the logic from Misc into common code with Fermentable so we can write the handling
+// for weight/volume once.  What's here for the moment is showing weight/volume but not allowing it to be edited.
+
 //=====================CLASS FermentableTableModel==============================
 FermentableTableModel::FermentableTableModel(QTableView* parent, bool editable) :
    BtTableModelInventory{
       parent,
       editable,
-      {{FERMNAMECOL,      {tr("Name"),      NonPhysicalQuantity::String,          ""            }},
-       {FERMTYPECOL,      {tr("Type"),      NonPhysicalQuantity::String,          ""            }},
-       {FERMAMOUNTCOL,    {tr("Amount"),    Measurement::PhysicalQuantity::Mass,  "amount_kg"   }},
-       {FERMINVENTORYCOL, {tr("Inventory"), Measurement::PhysicalQuantity::Mass,  "inventory_kg"}},
-       {FERMISMASHEDCOL,  {tr("Method"),    NonPhysicalQuantity::String,          ""            }},
-       {FERMAFTERBOIL,    {tr("Addition"),  NonPhysicalQuantity::String,          ""            }},
-       {FERMYIELDCOL,     {tr("Yield %"),   NonPhysicalQuantity::Percentage,      ""            }},
-       {FERMCOLORCOL,     {tr("Color"),     Measurement::PhysicalQuantity::Color, "color_srm"   }}}
+      {
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Name     , tr("Name"       ),           NonPhysicalQuantity::String    ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Type     , tr("Type"       ),           NonPhysicalQuantity::String    ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Amount   , tr("Amount"     ), Measurement::PhysicalQuantity::Mass      ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Inventory, tr("Inventory"  ), Measurement::PhysicalQuantity::Mass      ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, IsMashed , tr("Method"     ),           NonPhysicalQuantity::String    ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, AfterBoil, tr("Addition"   ),           NonPhysicalQuantity::String    ),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Yield    , tr("Yield %"    ),           NonPhysicalQuantity::Percentage),
+         SMART_COLUMN_HEADER_DEFN(FermentableTableModel, Color    , tr("Color"      ), Measurement::PhysicalQuantity::Color     ),
+      }
    },
    BtTableModelData<Fermentable>{},
    displayPercentages(false),
@@ -83,6 +116,10 @@ FermentableTableModel::FermentableTableModel(QTableView* parent, bool editable)
 
 FermentableTableModel::~FermentableTableModel() = default;
 
+BtTableModel::ColumnInfo const & FermentableTableModel::getColumnInfo(FermentableTableModel::ColumnIndex const columnIndex) const {
+   return this->BtTableModel::getColumnInfo(static_cast<size_t>(columnIndex));
+}
+
 void FermentableTableModel::observeRecipe(Recipe* rec) {
    if (this->recObs) {
       qDebug() << Q_FUNC_INFO << "Unobserve Recipe #" << this->recObs->key() << "(" << this->recObs->name() << ")";
@@ -227,8 +264,8 @@ void FermentableTableModel::changedInventory(int invKey, BtStringConst const & p
    if (propertyName == PropertyNames::Inventory::amount) {
       for (int ii = 0; ii < this->rows.size(); ++ii) {
          if (invKey == this->rows.at(ii)->inventoryId()) {
-            emit dataChanged(QAbstractItemModel::createIndex(ii, FERMINVENTORYCOL),
-                             QAbstractItemModel::createIndex(ii, FERMINVENTORYCOL));
+            emit dataChanged(QAbstractItemModel::createIndex(ii, static_cast<int>(FermentableTableModel::ColumnIndex::Inventory)),
+                             QAbstractItemModel::createIndex(ii, static_cast<int>(FermentableTableModel::ColumnIndex::Inventory)));
          }
       }
    }
@@ -247,7 +284,8 @@ void FermentableTableModel::changed(QMetaProperty prop, [[maybe_unused]] QVarian
       }
 
       this->updateTotalGrains();
-      emit dataChanged(QAbstractItemModel::createIndex(ii, 0), QAbstractItemModel::createIndex(ii, FERMNUMCOLS - 1));
+      emit dataChanged(QAbstractItemModel::createIndex(ii, 0),
+                       QAbstractItemModel::createIndex(ii, this->columnCount() - 1));
       if (displayPercentages && rowCount() > 0) {
          emit headerDataChanged(Qt::Vertical, 0, rowCount() - 1);
       }
@@ -282,76 +320,74 @@ QVariant FermentableTableModel::data(QModelIndex const & index, int role) const
       return QVariant();
    }
 
-   int const column = index.column();
-   switch (column) {
-      case FERMNAMECOL:
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   switch (columnIndex) {
+      case FermentableTableModel::ColumnIndex::Name:
          if (role == Qt::DisplayRole) {
             return QVariant(row->name());
          }
          break;
-      case FERMTYPECOL:
+      case FermentableTableModel::ColumnIndex::Type:
          if (role == Qt::DisplayRole) {
-            return QVariant(row->typeStringTr());
+            return QVariant(Fermentable::typeDisplayNames[row->type()]);
          }
          if (role == Qt::UserRole) {
             return QVariant(static_cast<int>(row->type()));
          }
          break;
-      case FERMINVENTORYCOL:
+      case FermentableTableModel::ColumnIndex::Inventory:
          if (role == Qt::DisplayRole) {
-            // So just query the columns
             return QVariant(
                Measurement::displayAmount(Measurement::Amount{row->inventory(), Measurement::Units::kilograms},
                                           3,
-                                          this->getForcedSystemOfMeasurementForColumn(column),
-                                          this->getForcedRelativeScaleForColumn(column))
+                                          this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
+                                          std::nullopt)
             );
          }
          break;
-      case FERMAMOUNTCOL:
+      case FermentableTableModel::ColumnIndex::Amount:
          if (role == Qt::DisplayRole) {
-            // So just query the columns
             return QVariant(
                Measurement::displayAmount(Measurement::Amount{row->amount_kg(), Measurement::Units::kilograms},
                                           3,
-                                          this->getForcedSystemOfMeasurementForColumn(column),
-                                          this->getForcedRelativeScaleForColumn(column))
+                                          this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
+                                          std::nullopt)
             );
          }
          break;
-      case FERMISMASHEDCOL:
+      case FermentableTableModel::ColumnIndex::IsMashed:
          if (role == Qt::DisplayRole) {
-            return QVariant(row->additionMethodStringTr());
+            return QVariant(descIsMashed[static_cast<int>(row->isMashed())]);
          }
          if (role == Qt::UserRole) {
-            return QVariant(static_cast<int>(row->additionMethod()));
+            return QVariant(row->isMashed());
          }
          break;
-      case FERMAFTERBOIL:
+      case FermentableTableModel::ColumnIndex::AfterBoil:
          if (role == Qt::DisplayRole) {
-            return QVariant(row->additionTimeStringTr());
+            return QVariant(descAddAfterBoil[static_cast<int>(row->addAfterBoil())]);
          }
          if (role == Qt::UserRole) {
-            return QVariant(static_cast<int>(row->additionTime()));
+            return QVariant(row->addAfterBoil());
          }
          break;
-      case FERMYIELDCOL:
+      case FermentableTableModel::ColumnIndex::Yield:
          if (role == Qt::DisplayRole) {
             return QVariant(Measurement::displayQuantity(row->yield_pct(), 3));
          }
          break;
-      case FERMCOLORCOL:
+      case FermentableTableModel::ColumnIndex::Color:
          if (role == Qt::DisplayRole) {
             return QVariant(
                Measurement::displayAmount(Measurement::Amount{row->color_srm(), Measurement::Units::srm},
                                           0,
-                                          this->getForcedSystemOfMeasurementForColumn(column),
+                                          this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
                                           std::nullopt)
             );
          }
          break;
       default :
-         qCritical() << Q_FUNC_INFO << "Bad column: " << column;
+         qCritical() << Q_FUNC_INFO << "Bad column: " << index.column();
          break;
    }
    return QVariant();
@@ -359,7 +395,7 @@ QVariant FermentableTableModel::data(QModelIndex const & index, int role) const
 
 QVariant FermentableTableModel::headerData( int section, Qt::Orientation orientation, int role ) const {
    if (orientation == Qt::Horizontal && role == Qt::DisplayRole) {
-      return this->getColumName(section);
+      return this->getColumnLabel(section);
    }
 
    if (displayPercentages && orientation == Qt::Vertical && role == Qt::DisplayRole) {
@@ -377,23 +413,23 @@ Qt::ItemFlags FermentableTableModel::flags(const QModelIndex& index ) const {
    Qt::ItemFlags constexpr defaults = Qt::ItemIsEnabled;
    auto row = this->rows[index.row()];
 
-   int col = index.column();
-   switch (col) {
-      case FERMISMASHEDCOL:
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   switch (columnIndex) {
+      case FermentableTableModel::ColumnIndex::IsMashed:
          // Ensure that being mashed and being a late addition are mutually exclusive.
          if (!row->addAfterBoil()) {
             return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled);
          }
          return Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled;
-      case FERMAFTERBOIL:
+      case FermentableTableModel::ColumnIndex::AfterBoil:
          // Ensure that being mashed and being a late addition are mutually exclusive.
          if (!row->isMashed()) {
             return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled);
          }
          return Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) | Qt::ItemIsDragEnabled;
-      case FERMNAMECOL:
+      case FermentableTableModel::ColumnIndex::Name:
          return (defaults | Qt::ItemIsSelectable);
-      case FERMINVENTORYCOL:
+      case FermentableTableModel::ColumnIndex::Inventory:
          return (defaults | (this->isInventoryEditable() ? Qt::ItemIsEditable : Qt::NoItemFlags));
       default:
          return (defaults | Qt::ItemIsSelectable | (editable ? Qt::ItemIsEditable : Qt::NoItemFlags) );
@@ -411,9 +447,11 @@ bool FermentableTableModel::setData(QModelIndex const & index,
    bool retVal = false;
    auto row = this->rows[index.row()];
 
-   int const column = index.column();
-   switch (column) {
-      case FERMNAMECOL:
+   Measurement::PhysicalQuantity physicalQuantity = Measurement::PhysicalQuantity::Mass;
+
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   switch (columnIndex) {
+      case FermentableTableModel::ColumnIndex::Name:
          retVal = value.canConvert(QVariant::String);
          if (retVal) {
             MainWindow::instance().doOrRedoUpdate(*row,
@@ -422,7 +460,7 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                                                   tr("Change Fermentable Name"));
          }
          break;
-      case FERMTYPECOL:
+      case FermentableTableModel::ColumnIndex::Type:
          retVal = value.canConvert(QVariant::Int);
          if (retVal) {
             // Doing the set via doOrRedoUpdate() saves us from doing a static_cast<Fermentable::Type>() here (as the
@@ -433,7 +471,7 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                                                   tr("Change Fermentable Type"));
          }
          break;
-      case FERMINVENTORYCOL:
+      case FermentableTableModel::ColumnIndex::Inventory:
          retVal = value.canConvert(QVariant::String);
          if (retVal) {
             // Inventory amount is in kg, but is just called "inventory" rather than "inventory_kg" in the Q_PROPERTY declaration in the Fermentable class
@@ -441,14 +479,14 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                *row,
                PropertyNames::NamedEntityWithInventory::inventory,
                Measurement::qStringToSI(value.toString(),
-                                        Measurement::PhysicalQuantity::Mass,
-                                        this->getForcedSystemOfMeasurementForColumn(column),
-                                        this->getForcedRelativeScaleForColumn(column)).quantity,
-               tr("Change Inventory Amount")
+                                        physicalQuantity,
+                                        this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
+                                        this->getColumnInfo(columnIndex).getForcedRelativeScale()).quantity(),
+               tr("Change Fermentable Inventory Amount")
             );
          }
          break;
-      case FERMAMOUNTCOL:
+      case FermentableTableModel::ColumnIndex::Amount:
          retVal = value.canConvert(QVariant::String);
          if (retVal) {
             // This is where the amount of a fermentable in a recipe gets updated
@@ -458,8 +496,8 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                PropertyNames::Fermentable::amount_kg,
                Measurement::qStringToSI(value.toString(),
                                         Measurement::PhysicalQuantity::Mass,
-                                        this->getForcedSystemOfMeasurementForColumn(column),
-                                        this->getForcedRelativeScaleForColumn(column)).quantity,
+                                        this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
+                                        this->getColumnInfo(columnIndex).getForcedRelativeScale()).quantity(),
                tr("Change Fermentable Amount")
             );
             if (rowCount() > 0) {
@@ -467,29 +505,29 @@ bool FermentableTableModel::setData(QModelIndex const & index,
             }
          }
          break;
-      case FERMISMASHEDCOL:
+      case FermentableTableModel::ColumnIndex::IsMashed:
          retVal = value.canConvert(QVariant::Int);
          if (retVal) {
             // Doing the set via doOrRedoUpdate() saves us from doing a static_cast<Fermentable::AdditionMethod>() here
             // (as the Q_PROPERTY system will do the casting for us).
             MainWindow::instance().doOrRedoUpdate(*row,
-                                                  PropertyNames::Fermentable::additionMethod,
-                                                  value.toInt(),
-                                                  tr("Change Addition Method"));
+                                                  PropertyNames::Fermentable::isMashed,
+                                                  value.toBool(),
+                                                  tr("Change Fermentable Is Mashed"));
          }
          break;
-      case FERMAFTERBOIL:
-         retVal = value.canConvert(QVariant::Int);
+      case FermentableTableModel::ColumnIndex::AfterBoil:
+         retVal = value.canConvert(QVariant::Bool);
          if (retVal) {
             // Doing the set via doOrRedoUpdate() saves us from doing a static_cast<Fermentable::AdditionTime>() here
             // (as the Q_PROPERTY system will do the casting for us).
             MainWindow::instance().doOrRedoUpdate(*row,
-                                                  PropertyNames::Fermentable::additionTime,
-                                                  value.toInt(),
-                                                  tr("Change Addition Time"));
+                                                  PropertyNames::Fermentable::addAfterBoil,
+                                                  value.toBool(),
+                                                  tr("Change Add After Boil"));
          }
          break;
-      case FERMYIELDCOL:
+      case FermentableTableModel::ColumnIndex::Yield:
          retVal = value.canConvert(QVariant::Double);
          if (retVal) {
             MainWindow::instance().doOrRedoUpdate(*row,
@@ -498,7 +536,7 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                                                   tr("Change Yield"));
          }
          break;
-      case FERMCOLORCOL:
+      case FermentableTableModel::ColumnIndex::Color:
          retVal = value.canConvert(QVariant::Double);
          if (retVal) {
             MainWindow::instance().doOrRedoUpdate(
@@ -506,8 +544,8 @@ bool FermentableTableModel::setData(QModelIndex const & index,
                PropertyNames::Fermentable::color_srm,
                Measurement::qStringToSI(value.toString(),
                                         Measurement::PhysicalQuantity::Color,
-                                        this->getForcedSystemOfMeasurementForColumn(column),
-                                        this->getForcedRelativeScaleForColumn(column)).quantity,
+                                        this->getColumnInfo(columnIndex).getForcedSystemOfMeasurement(),
+                                        this->getColumnInfo(columnIndex).getForcedRelativeScale()).quantity(),
                tr("Change Color")
             );
          }
@@ -528,32 +566,25 @@ FermentableItemDelegate::FermentableItemDelegate(QObject* parent) : QItemDelegat
 QWidget* FermentableItemDelegate::createEditor(QWidget *parent,
                                                [[maybe_unused]] QStyleOptionViewItem const & option,
                                                QModelIndex const & index) const {
-   if (index.column() == FERMTYPECOL )
-   {
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   if (columnIndex == FermentableTableModel::ColumnIndex::Type) {
       QComboBox *box = new QComboBox(parent);
-
-      box->addItem(tr("Grain"));
-      box->addItem(tr("Sugar"));
-      box->addItem(tr("Extract"));
-      box->addItem(tr("Dry Extract"));
-      box->addItem(tr("Adjunct"));
+      for (auto ii : Fermentable::allTypes) {
+         box->addItem(Fermentable::typeDisplayNames[ii]);
+      }
 
       box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
       box->setFocusPolicy(Qt::StrongFocus);
 
       return box;
-   }
-
-   if (index.column() == FERMISMASHEDCOL )
-   {
+   } else if (columnIndex == FermentableTableModel::ColumnIndex::IsMashed) {
       QComboBox* box = new QComboBox(parent);
       QListWidget* list = new QListWidget(parent);
       list->setResizeMode(QListWidget::Adjust);
 
-      list->addItem(tr("Mashed"));
-      list->addItem(tr("Steeped"));
-      list->addItem(tr("Not mashed"));
+      list->addItem(descIsMashed[0]);
+      list->addItem(descIsMashed[1]);
       box->setModel(list->model());
       box->setView(list);
 
@@ -561,25 +592,12 @@ QWidget* FermentableItemDelegate::createEditor(QWidget *parent,
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
       box->setFocusPolicy(Qt::StrongFocus);
 
-      // Can we access to the data model into FermentableItemDelegate ? Yes we can !
-      int type = index.model()->index(index.row(), FERMTYPECOL).data(Qt::UserRole).toInt();
-
-      // Hide the unsuitable item keeping the same enumeration
-      if (type == static_cast<int>(Fermentable::Type::Grain)) {
-         list->item(static_cast<int>(Fermentable::AdditionMethod::Not_Mashed))->setHidden(true);
-      } else {
-         list->item(static_cast<int>(Fermentable::AdditionMethod::Steeped))->setHidden(true);
-      }
-
       return box;
-   }
-
-   if (index.column() == FERMAFTERBOIL )
-   {
+   } else if (columnIndex == FermentableTableModel::ColumnIndex::AfterBoil) {
       QComboBox* box = new QComboBox(parent);
 
-      box->addItem(tr("Normal"));
-      box->addItem(tr("Late"));
+      box->addItem(descAddAfterBoil[0]);
+      box->addItem(descAddAfterBoil[1]);
 
       box->setMinimumWidth(box->minimumSizeHint().width());
       box->setSizeAdjustPolicy(QComboBox::AdjustToContents);
@@ -591,60 +609,58 @@ QWidget* FermentableItemDelegate::createEditor(QWidget *parent,
    return new QLineEdit(parent);
 }
 
-void FermentableItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
-{
-   int col = index.column();
-
-   if (col == FERMTYPECOL || col == FERMISMASHEDCOL || col == FERMAFTERBOIL)
-   {
+void FermentableItemDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const {
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   if (columnIndex == FermentableTableModel::ColumnIndex::Type) {
       QComboBox* box = static_cast<QComboBox*>(editor);
-      int ndx = index.model()->data(index, Qt::UserRole).toInt();
-
-      box->setCurrentIndex(ndx);
-   }
-   else
-   {
-      QLineEdit* line = static_cast<QLineEdit*>(editor);
-
+      box->setCurrentIndex(index.model()->data(index, Qt::UserRole).toInt());
+   } else if (columnIndex == FermentableTableModel::ColumnIndex::IsMashed ||
+              columnIndex == FermentableTableModel::ColumnIndex::AfterBoil) {
+      QComboBox* box = static_cast<QComboBox*>(editor);
+      box->setCurrentIndex(static_cast<int>(index.model()->data(index, Qt::UserRole).toBool()));
+   } else {
+      QLineEdit* line = qobject_cast<QLineEdit*>(editor);
       line->setText(index.model()->data(index, Qt::DisplayRole).toString());
    }
+
+   return;
 }
 
-void FermentableItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
-{
-   int col = index.column();
-
-   if (col == FERMTYPECOL || col == FERMISMASHEDCOL || col == FERMAFTERBOIL )
-   {
+void FermentableItemDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const {
+   auto const columnIndex = static_cast<FermentableTableModel::ColumnIndex>(index.column());
+   if (columnIndex == FermentableTableModel::ColumnIndex::Type) {
       QComboBox* box = qobject_cast<QComboBox*>(editor);
       int value = box->currentIndex();
       int ndx = model->data(index, Qt::UserRole).toInt();
 
-     // Only do something when something needs to be done
-      if ( value != ndx )
+      // Only do something when something needs to be done
+      if (value != ndx) {
          model->setData(index, value, Qt::EditRole);
-   }
-   else if (col == FERMISMASHEDCOL || col == FERMAFTERBOIL )
-   {
+      }
+   } else if (columnIndex == FermentableTableModel::ColumnIndex::IsMashed ||
+              columnIndex == FermentableTableModel::ColumnIndex::AfterBoil) {
       QComboBox* box = qobject_cast<QComboBox*>(editor);
-      int value = box->currentIndex();
-      int ndx = model->data(index, Qt::UserRole).toInt();
+      bool value = box->currentIndex() > 0;
+      bool ndx = model->data(index, Qt::UserRole).toBool();
 
-     // Only do something when something needs to be done
-      if ( value != ndx )
+      // Only do something when something needs to be done
+      if (value != ndx) {
          model->setData(index, value, Qt::EditRole);
-   }
-   else
-   {
+      }
+   } else {
       QLineEdit* line = qobject_cast<QLineEdit*>(editor);
 
-      if ( line->isModified() )
-          model->setData(index, line->text(), Qt::EditRole);
+      if (line->isModified()) {
+         model->setData(index, line->text(), Qt::EditRole);
+      }
    }
+
+   return;
 }
 
 void FermentableItemDelegate::updateEditorGeometry(QWidget * editor,
                                                    QStyleOptionViewItem const & option,
                                                    [[maybe_unused]] QModelIndex const & index) const {
    editor->setGeometry(option.rect);
+   return;
 }
