@@ -1,6 +1,6 @@
 /*
  * FermentableTableModel.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Jeff Bailey <skydvr38@verizon.net>
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
@@ -44,8 +44,6 @@ class Fermentable;
 class Recipe;
 class FermentableItemDelegate;
 
-enum{FERMNAMECOL, FERMTYPECOL, FERMAMOUNTCOL, FERMINVENTORYCOL, FERMISMASHEDCOL, FERMAFTERBOIL, FERMYIELDCOL, FERMCOLORCOL, FERMNUMCOLS /*This one MUST be last*/};
-
 /*!
  * \class FermentableTableModel
  *
@@ -55,9 +53,23 @@ class FermentableTableModel : public BtTableModelInventory, public BtTableModelD
    Q_OBJECT
 
 public:
+   enum class ColumnIndex {
+      Name     ,
+      Type     ,
+      Amount   ,
+      Inventory,
+      IsMashed ,
+      AfterBoil,
+      Yield    ,
+      Color    ,
+   };
+
    FermentableTableModel(QTableView* parent=nullptr, bool editable=true);
    virtual ~FermentableTableModel();
 
+   //! \brief Casting wrapper for \c BtTableModel::getColumnInfo
+   ColumnInfo const & getColumnInfo(ColumnIndex const columnIndex) const;
+
    //! \brief Observe a recipe's list of fermentables.
    void observeRecipe(Recipe* rec);
    //! \brief If true, we model the database's list of fermentables.
