@@ -1,6 +1,6 @@
 /*
  * MiscTableModel.h is part of Brewtarget, and is Copyright the following
- * authors 2009-2021
+ * authors 2009-2023
  * - Jeff Bailey <skydvr38@verizon.net>
  * - Matt Young <mfsy@yahoo.com>
  * - Mik Firestone <mikfire@gmail.com>
@@ -46,8 +46,6 @@ class Misc;
 class MiscTableWidget;
 class Recipe;
 
-enum{MISCNAMECOL, MISCTYPECOL, MISCUSECOL, MISCTIMECOL, MISCAMOUNTCOL, MISCINVENTORYCOL, MISCISWEIGHT, MISCNUMCOLS /*This one MUST be last*/};
-
 /*!
  * \class MiscTableModel
  *
@@ -57,9 +55,22 @@ class MiscTableModel : public BtTableModelInventory, public BtTableModelData<Mis
    Q_OBJECT
 
 public:
+   enum class ColumnIndex {
+      Name     ,
+      Type     ,
+      Use      ,
+      Time     ,
+      Amount   ,
+      Inventory,
+      IsWeight ,
+   };
+
    MiscTableModel(QTableView* parent=nullptr, bool editable=true);
    virtual ~MiscTableModel();
 
+   //! \brief Casting wrapper for \c BtTableModel::getColumnInfo
+   ColumnInfo const & getColumnInfo(ColumnIndex const columnIndex) const;
+
    //! \brief Observe a recipe's list of miscs.
    void observeRecipe(Recipe* rec);
    //! \brief If true, we model the database's list of miscs.
@@ -93,6 +104,7 @@ private slots:
    void changedInventory(int invKey, BtStringConst const & propertyName);
 };
 
+
 /*!
  * \class MiscItemDelegate
  *
