@@ -1,9 +1,12 @@
 /*
- * Testing.cpp is part of Brewtarget, and is Copyright the following
- * authors 2009-2022
- * - Mattias Måhl <mattias@kejsarsten.com>
- * - Matt Young <mfsy@yahoo.com>
- * - Philip Lee <rocketman768@gmail.com>
+ * unitTests/Testing.cpp is part of Brewtarget, and is copyright the following authors 2009-2023:
+ *   • Brian Rower <brian.rower@gmail.com>
+ *   • Mattias Måhl <mattias@kejsarsten.com>
+ *   • Matt Young <mfsy@yahoo.com>
+ *   • Maxime Lavigne <duguigne@gmail.com>
+ *   • Mike Evans <mikee@saxicola.co.uk>
+ *   • Mik Firestone <mikfire@gmail.com>
+ *   • Philip Greggory Lee <rocketman768@gmail.com>
  *
  * Brewtarget is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,10 +18,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU General Public License along with this program.  If not, see
+ * <http://www.gnu.org/licenses/>.
  */
-#include "Testing.h"
+#include "unitTests/Testing.h"
 
 #include <cmath>
 #include <exception>
@@ -41,6 +44,7 @@
 #include "Algorithms.h"
 #include "config.h"
 #include "database/ObjectStoreWrapper.h"
+#include "Localization.h"
 #include "Logging.h"
 #include "measurement/Measurement.h"
 #include "measurement/Unit.h"
@@ -50,6 +54,7 @@
 #include "model/Hop.h"
 #include "model/Mash.h"
 #include "model/MashStep.h"
+#include "model/NamedParameterBundle.h"
 #include "model/Recipe.h"
 #include "PersistentSettings.h"
 
@@ -226,12 +231,12 @@ namespace {
 
 
    //! \brief True iff a <= c <= b
-   constexpr bool inRange(double c, double a, double b) {
+   constexpr bool inRange(double const c, double const a, double const b) {
       return (a <= c) && (c <= b);
    }
 
    //! \brief True iff b - tolerance <= a <= b + tolerance
-   bool fuzzyComp(double a, double b, double tolerance) {
+   bool fuzzyComp(double const a, double const b, double const tolerance) {
       bool ret = inRange(a, b - tolerance, b + tolerance);
       if (!ret) {
          qDebug() << Q_FUNC_INFO << "a:" << a << ", b:" << b << ", diff:" << abs(a - b) << ", tolerance:" << tolerance;
@@ -311,7 +316,7 @@ Testing::~Testing() {
       }
    }
    return;
-};
+}
 
 //
 // If you're building with CMake:
@@ -319,7 +324,7 @@ Testing::~Testing() {
 //   - Run unit tests with  make test
 //   - Debug log output is in build/Testing/Temporary/LastTest.log (assuming "build" is your CMake build directory)
 //
-// If you're building with Meson (which NB is not yet fully supported!):
+// If you're building with Meson:
 //   - Ensure each unit test has a "test" line in meson.build
 //   - Run unit tests with  meson test
 //   - Debug log output is in mbuild/meson-logs/testlog.txt (assuming "mbuild" is your Meson build directory)
@@ -363,8 +368,11 @@ void Testing::initTestCase() {
       // logging output to stderr.
       qDebug() << Q_FUNC_INFO << "Initialised";
 
-      PersistentSettings::insert(PersistentSettings::Names::color_formula, "morey");
-      PersistentSettings::insert(PersistentSettings::Names::ibu_formula, "tinseth");
+      // Setting French locale below forces ',' as decimal separator and '.' as thousands separator.  Hopefully this
+      // helps catch cases where we incorrectly assume locale 'C' etc.
+      PersistentSettings::insert(PersistentSettings::Names::color_formula, "morey"  );
+      PersistentSettings::insert(PersistentSettings::Names::ibu_formula  , "tinseth");
+      PersistentSettings::insert(PersistentSettings::Names::forcedLocale , "fr_FR"  );
 
    // Tell Brewtarget not to require any "user" input on starting
       Application::setInteractive(false);
@@ -421,8 +429,8 @@ void Testing::initTestCase() {
    return;
 }
 
-void Testing::recipeCalcTest_allGrain()
-{
+void Testing::recipeCalcTest_allGrain() {
+   // .:TODO:. Would be good to fix and reinstate this test...
    return;
    double const grain_kg = 5.0;
    double const conversion_l = grain_kg * 2.8; // 2.8 L/kg mash thickness
@@ -506,8 +514,8 @@ void Testing::recipeCalcTest_allGrain()
    QVERIFY2( fuzzyComp(rec->color_srm(),     srm,                srm*0.1), "Wrong color calculation" );
 }
 
-void Testing::postBoilLossOgTest()
-{
+void Testing::postBoilLossOgTest() {
+   // .:TODO:. Would be good to fix and reinstate this test...
    return;
    double const grain_kg = 5.0;
    Recipe* recNoLoss = new Recipe(QString("TestRecipe_noLoss"));
@@ -584,8 +592,8 @@ void Testing::testUnitConversions() {
    // However, this didn't seem to have any effect on a French locale Windows.
    // So Plan B is to construct test data based on the current locale settings.
    //
-   QString const decimalSeparator   = QLocale::system().decimalPoint();
-   QString const thousandsSeparator = QLocale::system().groupSeparator();
+   QString const decimalSeparator   = Localization::getLocale().decimalPoint();
+   QString const thousandsSeparator = Localization::getLocale().groupSeparator();
    qDebug() <<
       Q_FUNC_INFO << "Decimal separator is " << decimalSeparator << " | Thousands separator is " << thousandsSeparator;
    QString testInput{};
@@ -594,7 +602,7 @@ void Testing::testUnitConversions() {
    testInput.clear();
    testInputAsStream << "5" << decimalSeparator << "500 gal";
    QVERIFY2(fuzzyComp(Measurement::UnitSystems::volume_UsCustomary.qstringToSI(testInput, // "5.500 gal"
-                                                                               Measurement::Units::liters).quantity,
+                                                                               Measurement::Units::liters).quantity(),
                       20.820,
                       0.001),
             "Unit conversion error (US gallons to Litres v1)");
@@ -602,23 +610,28 @@ void Testing::testUnitConversions() {
    testInput.clear();
    testInputAsStream << "5" << decimalSeparator << "500";
    QVERIFY2(fuzzyComp(Measurement::UnitSystems::volume_UsCustomary.qstringToSI(testInput, // "5.500"
-                                                                               Measurement::Units::us_gallons).quantity,
+                                                                               Measurement::Units::us_gallons).quantity(),
                       20.820,
                       0.001),
             "Unit conversion error (US gallons to Litres v2)");
    // "5.500 gal"
+   // This is an ambiguous case where the units could be US gallons or Imperial gallons.  At the moment, we say either
+   // interpretation is valid (in the absence of any other context).
+   // 5.5 US gallons       ≈ 20.820 litres
+   // 5.5 Imperial gallons ≈ 25.004 litres
    testInput.clear();
    testInputAsStream << "5" << decimalSeparator << "500 gal";
-   QVERIFY2(fuzzyComp(Measurement::qStringToSI(testInput, // "5.500 gal"
-                                               Measurement::PhysicalQuantity::Volume).quantity,
-                      20.820,
-                      0.001),
-                      "Unit conversion error (US gallons to Litres v3)");
+   auto converted = Measurement::qStringToSI(testInput, // "5.500 gal"
+                                             Measurement::PhysicalQuantity::Volume);
+   qDebug() << Q_FUNC_INFO << testInput << "converted to" << converted;
+   QVERIFY2(fuzzyComp(converted.quantity(), 20.820, 0.001) ||
+            fuzzyComp(converted.quantity(), 25.004, 0.001),
+            "Unit conversion error (US or Imperial gallons to Litres v3)");
    // "9.994 P"
    testInput.clear();
    testInputAsStream << "9" << decimalSeparator << "994 P";
    QVERIFY2(fuzzyComp(Measurement::UnitSystems::density_Plato.qstringToSI(testInput, // "9.994 P"
-                                                                          Measurement::Units::sp_grav).quantity,
+                                                                          Measurement::Units::specificGravity).quantity(),
                       1.040,
                       0.001),
             "Unit conversion error (Plato to SG)");
@@ -627,7 +640,7 @@ void Testing::testUnitConversions() {
    testInputAsStream << "1" << thousandsSeparator << "083 ebc";
    QVERIFY2(
       fuzzyComp(Measurement::UnitSystems::color_StandardReferenceMethod.qstringToSI(testInput, // "1,083 ebc"
-                                                                                    Measurement::Units::srm).quantity,
+                                                                                    Measurement::Units::srm).quantity(),
                 550,
                 1),
       "Unit conversion error (EBC to SRM)"
@@ -636,6 +649,85 @@ void Testing::testUnitConversions() {
    return;
 }
 
+void Testing::testNamedParameterBundle() {
+
+   //
+   // First some basic tests
+   //
+   NamedParameterBundle npb;
+
+   BtStringConst const myInt{"myInt"};
+   npb.insert(myInt, 42);
+   QVERIFY2(npb.get(myInt).toInt() == 42, "Error retrieving int");
+
+   BtStringConst const myFalseBool{"myFalseBool"};
+   npb.insert(myFalseBool, false);
+   QVERIFY2(!npb.get(myFalseBool).toBool(), "Error retrieving false bool");
+
+   BtStringConst const myTrueBool{"myTrueBool"};
+   npb.insert(myTrueBool, true);
+   QVERIFY2(npb.get(myTrueBool).toBool(), "Error retrieving true bool");
+
+   BtStringConst const myString{"myString"};
+   npb.insert(myString, "Sing a string of sixpence");
+   QVERIFY2(npb.get(myString).toString() == "Sing a string of sixpence", "Error retrieving string");
+
+   BtStringConst const myDouble{"myDouble"};
+   npb.insert(myDouble, 3.1415926535897932384626433);
+   QVERIFY2(fuzzyComp(npb.get(myDouble).toDouble(),
+                      3.1415926535897932384626433,
+                      0.0000000001),
+            "Error retrieving double");
+
+///   //
+///   // Test that we can store an int and get it back as a strongly-typed enum
+///   //
+///   npb.insert(PropertyNames::Hop::type, static_cast<int>(Hop::Type::AromaAndFlavor));
+///   Hop::Type retrievedHopType = npb.val<Hop::Type>(PropertyNames::Hop::type);
+///   QVERIFY2(retrievedHopType == Hop::Type::AromaAndFlavor, "Int -> Strongly-typed enum failed");
+///
+///   //
+///   // Now test explicitly nullable fields
+///   //
+///   QVERIFY2(
+///      npb.optEnumVal<Fermentable::GrainGroup>(PropertyNames::Fermentable::grainGroup) == std::nullopt,
+///      "Error getting default value for optional enum"
+///   );
+///   std::optional<int> myOptional{static_cast<int>(Fermentable::GrainGroup::Smoked)};
+///   QVariant myVariant = QVariant::fromValue(myOptional);
+///   npb.insert(PropertyNames::Fermentable::grainGroup, myVariant);
+///
+///   QVariant retrievedValueA = npb.get(PropertyNames::Fermentable::grainGroup);
+///   std::optional<int> castValueA = retrievedValueA.value< std::optional<int> >();
+///   QVERIFY2(castValueA.has_value(), "Error retrieving optional enum");
+///   QVERIFY2(castValueA.value() == static_cast<int>(Fermentable::GrainGroup::Smoked),
+///            "Error retrieving optional enum as int");
+///
+///   auto retrievedValueB = npb.optEnumVal<Fermentable::GrainGroup>(PropertyNames::Fermentable::grainGroup);
+///   qDebug() <<
+///      Q_FUNC_INFO << "retrievedValueB=" << (retrievedValueB.has_value() ? static_cast<int>(*retrievedValueB) : -999) <<
+///      "; Fermentable::GrainGroup::Smoked = " << static_cast<int>(Fermentable::GrainGroup::Smoked);
+///   QVERIFY2(retrievedValueB.has_value(), "Expected value, got none");
+///   QVERIFY2(
+///      retrievedValueB.value() == Fermentable::GrainGroup::Smoked,
+///      "Error retrieving optional enum"
+///   );
+
+   return;
+}
+
+void Testing::testNumberDisplayAndParsing() {
+   // Per comment above, we should be seeing number formats in French locale here
+   // Eg: 1,234.56 in US locale = 1.234,56 in French locale
+   QVERIFY(fuzzyComp(1.23, Measurement::extractRawFromString<double>("1,23 %"                  ), 0.0000000001));
+   QVERIFY(fuzzyComp(3.45, Measurement::extractRawFromString<double>("  03,45 srm  "           ), 0.0000000001));
+   QVERIFY(fuzzyComp(6.78, Measurement::extractRawFromString<double>("\t6,78000000    bananas!"), 0.0000000001));
+   QVERIFY(1    == Measurement::extractRawFromString<int>   ("1,23 %"));
+   QVERIFY(3    == Measurement::extractRawFromString<int>   ("  03,45 srm  "));
+   QVERIFY(6    == Measurement::extractRawFromString<int>   ("\t6,78000000    bananas!"));
+   return;
+}
+
 void Testing::testAlgorithms() {
    for (auto const & ii : sgBrixEquivalances) {
       qDebug() <<
@@ -655,11 +747,23 @@ void Testing::testAlgorithms() {
    return;
 }
 
+void Testing::testTypeLookups() {
+///   QVERIFY2(Hop::typeLookup.getType(PropertyNames::Hop::alpha_pct).typeIndex == typeid(double),
+///            "PropertyNames::Hop::alpha_pct not a double");
+///   auto const & grainGroupTypeInfo = Fermentable::typeLookup.getType(PropertyNames::Fermentable::grainGroup);
+///   QVERIFY2(grainGroupTypeInfo.isOptional(),
+///            "PropertyNames::Fermentable::grainGroup not optional");
+///   QVERIFY2(grainGroupTypeInfo.classification == TypeInfo::Classification::OptionalEnum,
+///            "PropertyNames::Fermentable::grainGroup not optional enum");
+   return;
+}
 void Testing::testLogRotation() {
+   qDebug() << Q_FUNC_INFO << "Logging to" << Logging::getDirectory();
+
    // Turning off logging to stderr console, this is so you won't have to watch 100k rows generate in the console.
    Logging::setLoggingToStderr(false);
 
-   //generate 40 000 log rows giving roughly 10 files with dummy/random logs
+   // Generate 40 000 log rows giving roughly 10 files with dummy/random logs
    // This should have to log rotate a few times leaving 5 log files in the directory which we can test for size and number of files.
    for (int i=0; i < 8000; i++) {
       qDebug() << QString("iteration %1-1; (%2)").arg(i).arg(randomStringGenerator());
@@ -671,21 +775,24 @@ void Testing::testLogRotation() {
    // Put logging back to normal
    Logging::setLoggingToStderr(true);
 
+
    QFileInfoList fileList = Logging::getLogFileList();
+   qDebug() << Q_FUNC_INFO << "Logging::getLogFileList() has" << fileList.size() << "entries";
+   qDebug() << Q_FUNC_INFO << "Logging::logFileCount =" << Logging::logFileCount;
    //There is always a "logFileCount" number of old files + 1 current file
    QCOMPARE(fileList.size(), Logging::logFileCount + 1);
 
-   for (int i = 0; i < fileList.size(); i++)
-   {
+   qDebug() << Q_FUNC_INFO << "Logging::logFileSize =" << Logging::logFileSize;
+   for (int i = 0; i < fileList.size(); i++) {
       QFile f(QString(fileList.at(i).canonicalFilePath()));
+      qDebug() << Q_FUNC_INFO << "File" << f << "has size" << f.size();
       //Here we test if the file is more than 10% bigger than the specified logFileSize", if so, fail.
       QVERIFY2(f.size() <= (Logging::logFileSize * 1.1), "Wrong Sized file");
    }
    return;
 }
 
-void Testing::cleanupTestCase()
-{
+void Testing::cleanupTestCase() {
    Application::cleanup();
    Logging::terminateLogging();
    //Clean up the gibberish logs from disk by removing the
@@ -712,6 +819,10 @@ void Testing::cleanupTestCase()
 
 
 void Testing::pstdintTest() {
+   //
+   // .:TBD:. I'm not sure this is the most useful of unit tests.  We're effectively checking that one tiny part of the
+   // C++11 standard is correctly implemented by the compiler.
+   //
    QVERIFY( sizeof(int8_t) == 1 );
    QVERIFY( sizeof(int16_t) == 2 );
    QVERIFY( sizeof(int32_t) == 4 );
@@ -729,11 +840,11 @@ void Testing::pstdintTest() {
 }
 
 
-void Testing::runTest()
-{
+void Testing::runTest() {
+   // .:TBD:. We should probably retire this function... :o)
    QVERIFY( 1==1 );
    /*
-   MainWindow* mw = Application::mainWindow();
+   MainWindow& mw = Application::mainWindow();
    QVERIFY( mw );
    */
 }
